RPM Package Manager, CVS Repository
http://rpm5.org/cvs/
____________________________________________________________________________
Server: rpm5.org Name: Jeff Johnson
Root: /v/rpm/cvs Email: jbj@rpm5.org
Module: rpm Date: 11-Oct-2007 21:44:25
Branch: HEAD Handle: 2007101120442104
Modified files:
rpm CHANGES build.c
rpm/build build.c files.c names.c pack.c spec.c
rpm/lib depends.c fs.c fsm.c manifest.c package.c
poptALL.c poptI.c psm.c query.c rpmchecksig.c
rpmds.c rpmfc.c rpmfi.c rpmgi.c rpminstall.c
rpmlock.c rpmrollback.c rpmts.c transaction.c
verify.c
rpm/rpmdb db3.c pkgio.c rpmdb.c signature.c sqlite.c
rpm/rpmio rpmio.c rpmlog.c url.c
rpm/tools rpmcache.c
Log:
- eliminate rpmMessage, rpmlog instead.
- finish eliminating rpmError, rpmlog instead.
Summary:
Revision Changes Path
1.1669 +2 -1 rpm/CHANGES
2.111 +2 -2 rpm/build.c
2.118 +2 -2 rpm/build/build.c
1.265 +5 -5 rpm/build/files.c
1.33 +1 -1 rpm/build/names.c
2.232 +2 -2 rpm/build/pack.c
2.157 +2 -2 rpm/build/spec.c
1.344 +18 -18 rpm/lib/depends.c
2.58 +1 -1 rpm/lib/fs.c
2.132 +37 -37 rpm/lib/fsm.c
2.20 +1 -1 rpm/lib/manifest.c
2.169 +8 -8 rpm/lib/package.c
2.46 +2 -2 rpm/lib/poptALL.c
2.38 +2 -2 rpm/lib/poptI.c
2.236 +8 -8 rpm/lib/psm.c
2.187 +2 -2 rpm/lib/query.c
1.152 +1 -1 rpm/lib/rpmchecksig.c
2.68 +5 -5 rpm/lib/rpmds.c
1.21 +7 -7 rpm/lib/rpmfc.c
2.81 +7 -7 rpm/lib/rpmfi.c
2.36 +5 -5 rpm/lib/rpmgi.c
1.168 +12 -12 rpm/lib/rpminstall.c
2.16 +3 -3 rpm/lib/rpmlock.c
1.16 +6 -6 rpm/lib/rpmrollback.c
2.107 +7 -7 rpm/lib/rpmts.c
1.337 +11 -11 rpm/lib/transaction.c
2.170 +2 -2 rpm/lib/verify.c
1.76 +7 -7 rpm/rpmdb/db3.c
1.14 +6 -6 rpm/rpmdb/pkgio.c
1.173 +31 -31 rpm/rpmdb/rpmdb.c
1.6 +4 -4 rpm/rpmdb/signature.c
1.16 +25 -25 rpm/rpmdb/sqlite.c
1.96 +2 -2 rpm/rpmio/rpmio.c
2.34 +1 -1 rpm/rpmio/rpmlog.c
1.42 +3 -3 rpm/rpmio/url.c
2.16 +2 -2 rpm/tools/rpmcache.c
____________________________________________________________________________
patch -p0 <<'@@ .'
Index: rpm/CHANGES
============================================================================
$ cvs diff -u -r1.1668 -r1.1669 CHANGES
--- rpm/CHANGES 11 Oct 2007 19:14:36 -0000 1.1668
+++ rpm/CHANGES 11 Oct 2007 19:44:21 -0000 1.1669
@@ -1,5 +1,6 @@
4.5 -> 5.0:
- - jbj: finish eliminating rpmError.
+ - jbj: eliminate rpmMessage, rpmlog instead.
+ - jbj: finish eliminating rpmError, rpmlog instead.
- jbj: switch rpmdbRemove to use headerGetExtension.
- jbj: switch rpmdbAdd to use headerGetExtension. ~1Mb leaks w --rebuilddb.
- jbj: fix: headerGetExtension failed to return p.str correctly.
@@ .
patch -p0 <<'@@ .'
Index: rpm/build.c
============================================================================
$ cvs diff -u -r2.110 -r2.111 build.c
--- rpm/build.c 11 Oct 2007 19:14:36 -0000 2.110
+++ rpm/build.c 11 Oct 2007 19:44:21 -0000 2.111
@@ -38,7 +38,7 @@
ps = rpmtsProblems(ts);
if (rc == 0 && rpmpsNumProblems(ps) > 0) {
- rpmMessage(RPMMESS_ERROR, _("Failed build dependencies:\n"));
+ rpmlog(RPMLOG_ERR, _("Failed build dependencies:\n"));
rpmpsPrint(NULL, ps);
rc = 1;
}
@@ -304,7 +304,7 @@
else /* XXX Perform clean-up after last target build. */
ba->buildAmount |= cleanFlags;
- rpmMessage(RPMMESS_DEBUG, _(" target platform: %s\n"), target);
+ rpmlog(RPMLOG_DEBUG, _(" target platform: %s\n"), target);
/* Read in configuration for target. */
if (t != targets) {
@@ .
patch -p0 <<'@@ .'
Index: rpm/build/build.c
============================================================================
$ cvs diff -u -r2.117 -r2.118 build.c
--- rpm/build/build.c 11 Oct 2007 19:14:36 -0000 2.117
+++ rpm/build/build.c 11 Oct 2007 19:44:21 -0000 2.118
@@ -229,7 +229,7 @@
buildCmd = rpmExpand(mCmd, " ", buildScript, NULL);
(void) poptParseArgvString(buildCmd, &argc, &argv);
- rpmMessage(RPMMESS_NORMAL, _("Executing(%s): %s\n"), name, buildCmd);
+ rpmlog(RPMLOG_NOTICE, _("Executing(%s): %s\n"), name, buildCmd);
if (!(child = fork())) {
/*@-mods@*/
@@ -359,7 +359,7 @@
exit:
if (rc && rpmlogGetNrecs() > 0) {
- rpmMessage(RPMMESS_NORMAL, _("\n\nRPM build errors:\n"));
+ rpmlog(RPMLOG_NOTICE, _("\n\nRPM build errors:\n"));
rpmlogPrint(NULL);
}
@@ .
patch -p0 <<'@@ .'
Index: rpm/build/files.c
============================================================================
$ cvs diff -u -r1.264 -r1.265 files.c
--- rpm/build/files.c 11 Oct 2007 19:14:36 -0000 1.264
+++ rpm/build/files.c 11 Oct 2007 19:44:21 -0000 1.265
@@ -284,7 +284,7 @@
/*@-boundsread@*/
for (x = 0; x < count; x++) {
if ((currentTime - mtime[x]) > tc)
- rpmMessage(RPMMESS_WARNING, _("TIMECHECK failure: %s\n"), files[x]);
+ rpmlog(RPMLOG_WARNING, _("TIMECHECK failure: %s\n"), files[x]);
}
files = hfd(files, fnt);
/*@=boundsread@*/
@@ -1310,7 +1310,7 @@
flp[1].flags |= flp->flags;
if (!(flp[1].flags & RPMFILE_EXCLUDE))
- rpmMessage(RPMMESS_WARNING, _("File listed twice: %s\n"),
+ rpmlog(RPMLOG_WARNING, _("File listed twice: %s\n"),
flp->fileURL);
/* file mode */
@@ -2612,7 +2612,7 @@
}
rc = 0;
- rpmMessage(RPMMESS_NORMAL, _("Checking for unpackaged file(s): %s\n"), s);
+ rpmlog(RPMLOG_NOTICE, _("Checking for unpackaged file(s): %s\n"), s);
/*@-boundswrite@*/
rc = rpmfcExec(av_ckfile, fileList, &sb_stdout, 0);
@@ -2628,7 +2628,7 @@
t = getStringBuf(sb_stdout);
if ((*t != '\0') && (*t != '\n')) {
rc = (_unpackaged_files_terminate_build) ? 1 : 0;
- rpmMessage((rc ? RPMMESS_ERROR : RPMMESS_WARNING),
+ rpmlog((rc ? RPMLOG_ERR : RPMLOG_WARNING),
_("Installed (but unpackaged) file(s) found:\n%s"), t);
}
}
@@ -2659,7 +2659,7 @@
(void) headerMacrosLoad(pkg->header);
(void) headerGetExtension(pkg->header, RPMTAG_NVRA, NULL, &NVRA, NULL);
- rpmMessage(RPMMESS_NORMAL, _("Processing files: %s\n"), NVRA);
+ rpmlog(RPMLOG_NOTICE, _("Processing files: %s\n"), NVRA);
NVRA = _free(NVRA);
if ((rc = processPackageFiles(spec, pkg, installSpecialDoc, test)))
@@ .
patch -p0 <<'@@ .'
Index: rpm/build/names.c
============================================================================
$ cvs diff -u -r1.32 -r1.33 names.c
--- rpm/build/names.c 16 Jul 2007 01:32:26 -0000 1.32
+++ rpm/build/names.c 11 Oct 2007 19:44:21 -0000 1.33
@@ -234,7 +234,7 @@
if (hbn)
strcpy(hostname, hbn->h_name);
else
- rpmMessage(RPMMESS_WARNING,
+ rpmlog(RPMLOG_WARNING,
_("Could not canonicalize hostname: %s\n"), hostname);
oneshot = 1;
}
@@ .
patch -p0 <<'@@ .'
Index: rpm/build/pack.c
============================================================================
$ cvs diff -u -r2.231 -r2.232 pack.c
--- rpm/build/pack.c 11 Oct 2007 19:14:36 -0000 2.231
+++ rpm/build/pack.c 11 Oct 2007 19:44:21 -0000 2.232
@@ -668,7 +668,7 @@
#endif
if (addsig) {
- rpmMessage(RPMMESS_NORMAL, _("Generating signature: %d\n"), sigtag);
+ rpmlog(RPMLOG_NOTICE, _("Generating signature: %d\n"), sigtag);
(void) rpmAddSignature(sigh, sigtarget, sigtag, passPhrase);
}
@@ -818,7 +818,7 @@
}
if (rc == 0)
- rpmMessage(RPMMESS_NORMAL, _("Wrote: %s\n"), fileName);
+ rpmlog(RPMLOG_NOTICE, _("Wrote: %s\n"), fileName);
else
(void) Unlink(fileName);
@@ .
patch -p0 <<'@@ .'
Index: rpm/build/spec.c
============================================================================
$ cvs diff -u -r2.156 -r2.157 spec.c
--- rpm/build/spec.c 11 Oct 2007 19:14:36 -0000 2.156
+++ rpm/build/spec.c 11 Oct 2007 19:44:21 -0000 2.157
@@ -819,7 +819,7 @@
goto exit;
}
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
_("Query specfile for platform(s): %s\n"), targets);
for (t = targets; *t != '\0'; t = te) {
/* Parse out next target platform. */
@@ -832,7 +832,7 @@
te++;
/* Query spec for this target platform. */
- rpmMessage(RPMMESS_DEBUG, _(" target platform: %s\n"), target);
+ rpmlog(RPMLOG_DEBUG, _(" target platform: %s\n"), target);
/* Read in configuration for target. */
if (t != targets) {
rpmFreeMacros(NULL);
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/depends.c
============================================================================
$ cvs diff -u -r1.343 -r1.344 depends.c
--- rpm/lib/depends.c 7 Oct 2007 19:25:22 -0000 1.343
+++ rpm/lib/depends.c 11 Oct 2007 19:44:22 -0000 1.344
@@ -302,7 +302,7 @@
const char * pkgNEVR = rpmdsDNEVR(this);
const char * addNEVR = rpmdsDNEVR(oldChk);
if (rpmIsVerbose())
- rpmMessage(RPMMESS_WARNING,
+ rpmlog(RPMLOG_WARNING,
_("package %s was already added, skipping %s\n"),
(pkgNEVR ? pkgNEVR + 2 : "?pkgNEVR?"),
(addNEVR ? addNEVR + 2 : "?addNEVR?"));
@@ -316,7 +316,7 @@
const char * pkgNEVR = rpmdsDNEVR(this);
const char * addNEVR = rpmdsDNEVR(newChk);
if (rpmIsVerbose())
- rpmMessage(RPMMESS_WARNING,
+ rpmlog(RPMLOG_WARNING,
_("package %s was already added, replacing with %s\n"),
(pkgNEVR ? pkgNEVR + 2 : "?pkgNEVR?"),
(addNEVR ? addNEVR + 2 : "?addNEVR?"));
@@ -424,7 +424,7 @@
xx = rpmteChain(p, q, oh, "Upgrades");
/*@-nullptrarith@*/
- rpmMessage(RPMMESS_DEBUG, D_(" upgrade erases %s\n"), rpmteNEVRA(q));
+ rpmlog(RPMLOG_DEBUG, D_(" upgrade erases %s\n"), rpmteNEVRA(q));
/*@=nullptrarith@*/
}
@@ -501,7 +501,7 @@
xx = rpmteChain(p, q, oh, "Obsoletes");
/*@-nullptrarith@*/
- rpmMessage(RPMMESS_DEBUG, D_(" Obsoletes: %s\t\terases %s\n"),
+ rpmlog(RPMLOG_DEBUG, D_(" Obsoletes: %s\t\terases %s\n"),
rpmdsDNEVR(obsoletes)+2, rpmteNEVRA(q));
/*@=nullptrarith@*/
}
@@ -1446,7 +1446,7 @@
const char ** av = NULL;
int anaconda = rpmtsDFlags(ts) & RPMDEPS_FLAG_ANACONDA;
int msglvl = (anaconda || (rpmtsDFlags(ts) & RPMDEPS_FLAG_DEPLOOPS))
- ? RPMMESS_WARNING : RPMMESS_DEBUG;
+ ? RPMLOG_WARNING : RPMLOG_DEBUG;
int ac = 0;
int i;
@@ -1467,7 +1467,7 @@
/*@-usereleased@*/
bdp->qname = qname;
/*@=usereleased@*/
- rpmMessage(msglvl,
+ rpmlog(msglvl,
_("ignore package name relation(s) [%d]\t%s -> %s\n"),
i, bdp->pname, (bdp->qname ? bdp->qname : "???"));
}
@@ -1590,7 +1590,7 @@
* Attempt to unravel a dependency loop by eliminating Requires's.
*/
if (zap) {
- rpmMessage(msglvl,
+ rpmlog(msglvl,
_("removing %s \"%s\" from tsort relations.\n"),
(rpmteNEVRA(p) ? rpmteNEVRA(p) : "???"), dp);
rpmteTSI(p)->tsi_count--;
@@ -1877,7 +1877,7 @@
pi = rpmtsiFree(pi);
/* Record all relations. */
- rpmMessage(RPMMESS_DEBUG, D_("========== recording tsort relations\n"));
+ rpmlog(RPMLOG_DEBUG, D_("========== recording tsort relations\n"));
pi = rpmtsiInit(ts);
while ((p = rpmtsiNext(pi, oType)) != NULL) {
@@ -1998,7 +1998,7 @@
ts->ntrees = treex;
/* T4. Scan for zeroes. */
- rpmMessage(RPMMESS_DEBUG, D_("========== tsorting packages (order, #predecessors, #succesors, tree, Ldepth, Rbreadth)\n"));
+ rpmlog(RPMLOG_DEBUG, D_("========== tsorting packages (order, #predecessors, #succesors, tree, Ldepth, Rbreadth)\n"));
rescan:
if (pi != NULL) pi = rpmtsiFree(pi);
@@ -2046,7 +2046,7 @@
breadth = ((depth < npeer) ? peer[depth]++ : 0);
(void) rpmteSetBreadth(q, breadth);
- rpmMessage(RPMMESS_DEBUG, "%5d%5d%5d%5d%5d%5d %*s%c%s\n",
+ rpmlog(RPMLOG_DEBUG, "%5d%5d%5d%5d%5d%5d %*s%c%s\n",
orderingCount, rpmteNpreds(q),
rpmteTSI(q)->tsi_qcnt,
treex, depth, breadth,
@@ -2088,7 +2088,7 @@
if (!_printed && loopcheck == qlen && rpmteTSI(q)->tsi_suc != NULL) {
_printed++;
(void) rpmtsUnorderedSuccessors(ts, orderingCount);
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
D_("========== successors only (%d bytes)\n"), (int)tsbytes);
/* Relink the queue in presentation order. */
@@ -2155,14 +2155,14 @@
const char * dp;
char buf[4096];
int msglvl = (anaconda || (rpmtsDFlags(ts) & RPMDEPS_FLAG_DEPLOOPS))
- ? RPMMESS_WARNING : RPMMESS_DEBUG;
+ ? RPMLOG_WARNING : RPMLOG_DEBUG;
;
/* Unchain predecessor loop. */
rpmteTSI(p)->tsi_chain = NULL;
if (!printed) {
- rpmMessage(msglvl, _("LOOP:\n"));
+ rpmlog(msglvl, _("LOOP:\n"));
printed = 1;
}
@@ -2173,7 +2173,7 @@
buf[0] = '\0';
if (rpmteNEVRA(p) != NULL)
(void) stpcpy(buf, rpmteNEVRA(p));
- rpmMessage(msglvl, " %-40s %s\n", buf,
+ rpmlog(msglvl, " %-40s %s\n", buf,
(dp ? dp : "not found!?!"));
dp = _free(dp);
@@ -2193,12 +2193,12 @@
/* If a relation was eliminated, then continue sorting. */
/* XXX TODO: add control bit. */
if (nzaps && nrescans-- > 0) {
- rpmMessage(RPMMESS_DEBUG, D_("========== continuing tsort ...\n"));
+ rpmlog(RPMLOG_DEBUG, D_("========== continuing tsort ...\n"));
goto rescan;
}
/* Return no. of packages that could not be ordered. */
- rpmMessage(RPMMESS_ERROR, _("rpmtsOrder failed, %d elements remain\n"),
+ rpmlog(RPMLOG_ERR, _("rpmtsOrder failed, %d elements remain\n"),
loopcheck);
#ifdef NOTYET
@@ -2306,7 +2306,7 @@
rpmds provides, requires, conflicts, dirnames, linktos;
/*@-nullpass@*/ /* FIX: rpmts{A,O} can return null. */
- rpmMessage(RPMMESS_DEBUG, "========== +++ %s %s/%s 0x%x\n",
+ rpmlog(RPMLOG_DEBUG, "========== +++ %s %s/%s 0x%x\n",
rpmteNEVR(p), rpmteA(p), rpmteO(p), rpmteColor(p));
/*@=nullpass@*/
requires = (!(depFlags & RPMDEPS_FLAG_NOREQUIRES)
@@ -2370,7 +2370,7 @@
rpmfi fi;
/*@-nullpass@*/ /* FIX: rpmts{A,O} can return null. */
- rpmMessage(RPMMESS_DEBUG, "========== --- %s %s/%s 0x%x\n",
+ rpmlog(RPMLOG_DEBUG, "========== --- %s %s/%s 0x%x\n",
rpmteNEVR(p), rpmteA(p), rpmteO(p), rpmteColor(p));
/*@=nullpass@*/
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/fs.c
============================================================================
$ cvs diff -u -r2.57 -r2.58 fs.c
--- rpm/lib/fs.c 11 Oct 2007 19:14:37 -0000 2.57
+++ rpm/lib/fs.c 11 Oct 2007 19:44:22 -0000 2.58
@@ -238,7 +238,7 @@
filesystems[numFilesystems].mntPoint = xstrdup(mntdir);
filesystems[numFilesystems].rdonly = rdonly;
#if 0
- rpmMessage(RPMMESS_DEBUG, _("%5d 0x%04x %s %s\n"),
+ rpmlog(RPMLOG_DEBUG, _("%5d 0x%04x %s %s\n"),
numFilesystems,
(unsigned) filesystems[numFilesystems].dev,
(filesystems[numFilesystems].rdonly ? "ro" : "rw"),
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/fsm.c
============================================================================
$ cvs diff -u -r2.131 -r2.132 fsm.c
--- rpm/lib/fsm.c 11 Oct 2007 19:14:37 -0000 2.131
+++ rpm/lib/fsm.c 11 Oct 2007 19:44:22 -0000 2.132
@@ -339,14 +339,14 @@
if (!dnli->active[i]) continue;
if (j == 0) {
j = 1;
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
D_("========== Directories not explicitly included in package:\n"));
}
(void) urlPath(fi->dnl[i], &dnl);
- rpmMessage(RPMMESS_DEBUG, "%10d %s\n", i, dnl);
+ rpmlog(RPMLOG_DEBUG, "%10d %s\n", i, dnl);
}
if (j)
- rpmMessage(RPMMESS_DEBUG, "==========\n");
+ rpmlog(RPMLOG_DEBUG, "==========\n");
}
}
return dnli;
@@ -766,7 +766,7 @@
if (fi->fuser && unameToUid(fi->fuser[i], &uid)) {
if (fsm->goal == FSM_PKGINSTALL)
- rpmMessage(RPMMESS_WARNING,
+ rpmlog(RPMLOG_WARNING,
_("user %s does not exist - using root\n"), fi->fuser[i]);
uid = 0;
finalMode &= ~S_ISUID; /* turn off suid bit */
@@ -774,7 +774,7 @@
if (fi->fgroup && gnameToGid(fi->fgroup[i], &gid)) {
if (fsm->goal == FSM_PKGINSTALL)
- rpmMessage(RPMMESS_WARNING,
+ rpmlog(RPMLOG_WARNING,
_("group %s does not exist - using root\n"), fi->fgroup[i]);
gid = 0;
finalMode &= ~S_ISGID; /* turn off sgid bit */
@@ -1358,11 +1358,11 @@
rc = fsmNext(fsm, FSM_LSETFCON);
}
if (fsm->fcontext == NULL)
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
D_("%s directory created with perms %04o, no context.\n"),
fsm->path, (unsigned)(st->st_mode & 07777));
else
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
D_("%s directory created with perms %04o, context %s.\n"),
fsm->path, (unsigned)(st->st_mode & 07777),
fsm->fcontext);
@@ -1458,7 +1458,7 @@
/* do nothing */
} else if (stage & FSM_INTERNAL) {
if (_fsm_debug && !(stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s %06o%3d (%4d,%4d)%12lu %s %s\n",
+ rpmlog(RPMLOG_DEBUG, " %8s %06o%3d (%4d,%4d)%12lu %s %s\n",
cur,
(unsigned)st->st_mode, (int)st->st_nlink,
(int)st->st_uid, (int)st->st_gid, (unsigned long)st->st_size,
@@ -1470,7 +1470,7 @@
(void) urlPath(fsm->path, &apath);
fsm->stage = stage;
if (_fsm_debug || !(stage & FSM_VERBOSE))
- rpmMessage(RPMMESS_DEBUG, "%-8s %06o%3d (%4d,%4d)%12lu %s %s\n",
+ rpmlog(RPMLOG_DEBUG, "%-8s %06o%3d (%4d,%4d)%12lu %s %s\n",
cur,
(unsigned)st->st_mode, (int)st->st_nlink,
(int)st->st_uid, (int)st->st_gid, (unsigned long)st->st_size,
@@ -1666,7 +1666,7 @@
if (fsm->ix < 0) {
if (fsm->goal == FSM_PKGINSTALL) {
#if 0
- rpmMessage(RPMMESS_WARNING,
+ rpmlog(RPMLOG_WARNING,
_("archive file %s was not found in header file list\n"),
fsm->path);
#endif
@@ -1810,7 +1810,7 @@
fsm->path = fsmFsPath(fsm, st, NULL, fsm->osuffix);
rc = fsmNext(fsm, FSM_RENAME);
if (!rc)
- rpmMessage(RPMMESS_WARNING,
+ rpmlog(RPMLOG_WARNING,
_("%s saved as %s\n"),
(fsm->opath ? fsm->opath : ""),
(fsm->path ? fsm->path : ""));
@@ -1931,7 +1931,7 @@
fsm->path = fsmFsPath(fsm, st, NULL, fsm->osuffix);
rc = fsmNext(fsm, FSM_RENAME);
if (!rc) {
- rpmMessage(RPMMESS_WARNING, _("%s saved as %s\n"),
+ rpmlog(RPMLOG_WARNING, _("%s saved as %s\n"),
(fsm->opath ? fsm->opath : ""),
(fsm->path ? fsm->path : ""));
}
@@ -2004,7 +2004,7 @@
(void) Unlink(fsm->opath);
else if (fsm->nsuffix) {
const char * opath = fsmFsPath(fsm, st, NULL, NULL);
- rpmMessage(RPMMESS_WARNING, _("%s created as %s\n"),
+ rpmlog(RPMLOG_WARNING, _("%s created as %s\n"),
(opath ? opath : ""),
(fsm->path ? fsm->path : ""));
opath = _free(opath);
@@ -2149,7 +2149,7 @@
}
rc = Unlink(fsm->path);
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s) %s\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s) %s\n", cur,
fsm->path, (rc < 0 ? strerror(errno) : ""));
if (rc < 0)
rc = (errno == ENOENT ? CPIOERR_ENOENT : CPIOERR_UNLINK_FAILED);
@@ -2180,14 +2180,14 @@
}
#endif
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, %s) %s\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, %s) %s\n", cur,
fsm->opath, fsm->path, (rc < 0 ? strerror(errno) : ""));
if (rc < 0) rc = CPIOERR_RENAME_FAILED;
break;
case FSM_MKDIR:
rc = Mkdir(fsm->path, (st->st_mode & 07777));
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, 0%04o) %s\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, 0%04o) %s\n", cur,
fsm->path, (unsigned)(st->st_mode & 07777),
(rc < 0 ? strerror(errno) : ""));
if (rc < 0) rc = CPIOERR_MKDIR_FAILED;
@@ -2195,7 +2195,7 @@
case FSM_RMDIR:
rc = Rmdir(fsm->path);
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s) %s\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s) %s\n", cur,
fsm->path, (rc < 0 ? strerror(errno) : ""));
if (rc < 0)
switch (errno) {
@@ -2212,7 +2212,7 @@
(void) urlPath(fsm->path, &fsmpath); /* XXX fsm->path */
rc = lsetfilecon(fsmpath, (security_context_t)fsm->fcontext);
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, %s) %s\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, %s) %s\n", cur,
fsm->path, fsm->fcontext,
(rc < 0 ? strerror(errno) : ""));
if (rc < 0) rc = (errno == EOPNOTSUPP ? 0 : CPIOERR_LSETFCON_FAILED);
@@ -2220,7 +2220,7 @@
case FSM_CHOWN:
rc = Chown(fsm->path, st->st_uid, st->st_gid);
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, %d, %d) %s\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, %d, %d) %s\n", cur,
fsm->path, (int)st->st_uid, (int)st->st_gid,
(rc < 0 ? strerror(errno) : ""));
if (rc < 0) rc = CPIOERR_CHOWN_FAILED;
@@ -2229,7 +2229,7 @@
#if ! CHOWN_FOLLOWS_SYMLINK
rc = Lchown(fsm->path, st->st_uid, st->st_gid);
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, %d, %d) %s\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, %d, %d) %s\n", cur,
fsm->path, (int)st->st_uid, (int)st->st_gid,
(rc < 0 ? strerror(errno) : ""));
if (rc < 0) rc = CPIOERR_CHOWN_FAILED;
@@ -2238,7 +2238,7 @@
case FSM_CHMOD:
rc = Chmod(fsm->path, (st->st_mode & 07777));
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, 0%04o) %s\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, 0%04o) %s\n", cur,
fsm->path, (unsigned)(st->st_mode & 07777),
(rc < 0 ? strerror(errno) : ""));
if (rc < 0) rc = CPIOERR_CHMOD_FAILED;
@@ -2249,7 +2249,7 @@
stamp.modtime = st->st_mtime;
rc = Utime(fsm->path, &stamp);
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, 0x%x) %s\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, 0x%x) %s\n", cur,
fsm->path, (unsigned)st->st_mtime,
(rc < 0 ? strerror(errno) : ""));
if (rc < 0) rc = CPIOERR_UTIME_FAILED;
@@ -2258,21 +2258,21 @@
case FSM_SYMLINK:
rc = Symlink(fsm->lpath, fsm->path);
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, %s) %s\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, %s) %s\n", cur,
fsm->lpath, fsm->path, (rc < 0 ? strerror(errno) : ""));
if (rc < 0) rc = CPIOERR_SYMLINK_FAILED;
break;
case FSM_LINK:
rc = Link(fsm->opath, fsm->path);
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, %s) %s\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, %s) %s\n", cur,
fsm->opath, fsm->path, (rc < 0 ? strerror(errno) : ""));
if (rc < 0) rc = CPIOERR_LINK_FAILED;
break;
case FSM_MKFIFO:
rc = Mkfifo(fsm->path, (st->st_mode & 07777));
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, 0%04o) %s\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, 0%04o) %s\n", cur,
fsm->path, (unsigned)(st->st_mode & 07777),
(rc < 0 ? strerror(errno) : ""));
if (rc < 0) rc = CPIOERR_MKFIFO_FAILED;
@@ -2282,7 +2282,7 @@
rc = Mknod(fsm->path, (st->st_mode & ~07777), st->st_rdev);
/*@=unrecog =portability @*/
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, 0%o, 0x%x) %s\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, 0%o, 0x%x) %s\n", cur,
fsm->path, (unsigned)(st->st_mode & ~07777),
(unsigned)st->st_rdev,
(rc < 0 ? strerror(errno) : ""));
@@ -2291,7 +2291,7 @@
case FSM_LSTAT:
rc = Lstat(fsm->path, ost);
if (_fsm_debug && (stage & FSM_SYSCALL) && rc && errno != ENOENT)
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, ost) %s\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, ost) %s\n", cur,
fsm->path, (rc < 0 ? strerror(errno) : ""));
if (rc < 0) {
rc = (errno == ENOENT ? CPIOERR_ENOENT : CPIOERR_LSTAT_FAILED);
@@ -2301,7 +2301,7 @@
case FSM_STAT:
rc = Stat(fsm->path, ost);
if (_fsm_debug && (stage & FSM_SYSCALL) && rc && errno != ENOENT)
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, ost) %s\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, ost) %s\n", cur,
fsm->path, (rc < 0 ? strerror(errno) : ""));
if (rc < 0) {
rc = (errno == ENOENT ? CPIOERR_ENOENT : CPIOERR_STAT_FAILED);
@@ -2312,7 +2312,7 @@
/* XXX NUL terminated result in fsm->rdbuf, len in fsm->rdnb. */
rc = Readlink(fsm->path, fsm->rdbuf, fsm->rdsize - 1);
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, rdbuf, %d) %s\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, rdbuf, %d) %s\n", cur,
fsm->path, (int)(fsm->rdsize -1), (rc < 0 ? strerror(errno) : ""));
if (rc < 0) rc = CPIOERR_READLINK_FAILED;
else {
@@ -2372,7 +2372,7 @@
case FSM_DREAD:
fsm->rdnb = Fread(fsm->wrbuf, sizeof(*fsm->wrbuf), fsm->wrlen, fsm->cfd);
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, %d, cfd)\trdnb %d\n",
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, %d, cfd)\trdnb %d\n",
cur, (fsm->wrbuf == fsm->wrb ? "wrbuf" : "mmap"),
(int)fsm->wrlen, (int)fsm->rdnb);
if (fsm->rdnb != fsm->wrlen || Ferror(fsm->cfd))
@@ -2383,7 +2383,7 @@
case FSM_DWRITE:
fsm->wrnb = Fwrite(fsm->rdbuf, sizeof(*fsm->rdbuf), fsm->rdnb, fsm->cfd);
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, %d, cfd)\twrnb %d\n",
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, %d, cfd)\twrnb %d\n",
cur, (fsm->rdbuf == fsm->rdb ? "rdbuf" : "mmap"),
(int)fsm->rdnb, (int)fsm->wrnb);
if (fsm->rdnb != fsm->wrnb || Ferror(fsm->cfd))
@@ -2401,13 +2401,13 @@
break;
}
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, \"r\") rfd %p rdbuf %p\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, \"r\") rfd %p rdbuf %p\n", cur,
fsm->path, fsm->rfd, fsm->rdbuf);
break;
case FSM_READ:
fsm->rdnb = Fread(fsm->rdbuf, sizeof(*fsm->rdbuf), fsm->rdlen, fsm->rfd);
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (rdbuf, %d, rfd)\trdnb %d\n",
+ rpmlog(RPMLOG_DEBUG, " %8s (rdbuf, %d, rfd)\trdnb %d\n",
cur, (int)fsm->rdlen, (int)fsm->rdnb);
if (fsm->rdnb != fsm->rdlen || Ferror(fsm->rfd))
rc = CPIOERR_READ_FAILED;
@@ -2415,7 +2415,7 @@
case FSM_RCLOSE:
if (fsm->rfd != NULL) {
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%p)\n", cur, fsm->rfd);
+ rpmlog(RPMLOG_DEBUG, " %8s (%p)\n", cur, fsm->rfd);
(void) rpmswAdd(rpmtsOp(fsmGetTs(fsm), RPMTS_OP_DIGEST),
fdstat_op(fsm->rfd, FDSTAT_DIGEST));
(void) Fclose(fsm->rfd);
@@ -2431,13 +2431,13 @@
rc = CPIOERR_OPEN_FAILED;
}
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%s, \"w\") wfd %p wrbuf %p\n", cur,
+ rpmlog(RPMLOG_DEBUG, " %8s (%s, \"w\") wfd %p wrbuf %p\n", cur,
fsm->path, fsm->wfd, fsm->wrbuf);
break;
case FSM_WRITE:
fsm->wrnb = Fwrite(fsm->wrbuf, sizeof(*fsm->wrbuf), fsm->rdnb, fsm->wfd);
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (wrbuf, %d, wfd)\twrnb %d\n",
+ rpmlog(RPMLOG_DEBUG, " %8s (wrbuf, %d, wfd)\twrnb %d\n",
cur, (int)fsm->rdnb, (int)fsm->wrnb);
if (fsm->rdnb != fsm->wrnb || Ferror(fsm->wfd))
rc = CPIOERR_WRITE_FAILED;
@@ -2445,7 +2445,7 @@
case FSM_WCLOSE:
if (fsm->wfd != NULL) {
if (_fsm_debug && (stage & FSM_SYSCALL))
- rpmMessage(RPMMESS_DEBUG, " %8s (%p)\n", cur, fsm->wfd);
+ rpmlog(RPMLOG_DEBUG, " %8s (%p)\n", cur, fsm->wfd);
(void) rpmswAdd(rpmtsOp(fsmGetTs(fsm), RPMTS_OP_DIGEST),
fdstat_op(fsm->wfd, FDSTAT_DIGEST));
(void) Fclose(fsm->wfd);
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/manifest.c
============================================================================
$ cvs diff -u -r2.19 -r2.20 manifest.c
--- rpm/lib/manifest.c 11 Oct 2007 02:04:38 -0000 2.19
+++ rpm/lib/manifest.c 11 Oct 2007 19:44:22 -0000 2.20
@@ -141,7 +141,7 @@
rpmrc = rpmGlob(s, &ac, &av);
if (rpmrc != RPMRC_OK) goto exit;
- rpmMessage(RPMMESS_DEBUG, D_("adding %d args from manifest.\n"), ac);
+ rpmlog(RPMLOG_DEBUG, D_("adding %d args from manifest.\n"), ac);
/* Count non-NULL args, keeping track of 1st arg after last NULL. */
npre = 0;
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/package.c
============================================================================
$ cvs diff -u -r2.168 -r2.169 package.c
--- rpm/lib/package.c 11 Oct 2007 19:14:37 -0000 2.168
+++ rpm/lib/package.c 11 Oct 2007 19:44:22 -0000 2.169
@@ -360,7 +360,7 @@
/* Parse the parameters from the OpenPGP packets that will be needed. */
xx = pgpPrtPkts(sig, siglen, dig, (_print_pkts & rpmIsDebug()));
if (dig->signature.version != 3 && dig->signature.version != 4) {
- rpmMessage(RPMMESS_ERROR,
+ rpmlog(RPMLOG_ERR,
_("skipping package %s with unverifiable V%u signature\n"),
fn, dig->signature.version);
rc = RPMRC_FAIL;
@@ -392,7 +392,7 @@
/* Parse the parameters from the OpenPGP packets that will be needed. */
xx = pgpPrtPkts(sig, siglen, dig, (_print_pkts & rpmIsDebug()));
if (dig->signature.version != 3 && dig->signature.version != 4) {
- rpmMessage(RPMMESS_ERROR,
+ rpmlog(RPMLOG_ERR,
_("skipping package %s with unverifiable V%u signature\n"),
fn, dig->signature.version);
rc = RPMRC_FAIL;
@@ -435,7 +435,7 @@
xx = pgpPrtPkts(sig, siglen, dig, (_print_pkts & rpmIsDebug()));
if (dig->signature.version != 3 && dig->signature.version != 4) {
- rpmMessage(RPMMESS_ERROR,
+ rpmlog(RPMLOG_ERR,
_("skipping package %s with unverifiable V%u signature\n"),
fn, dig->signature.version);
rc = RPMRC_FAIL;
@@ -491,20 +491,20 @@
rc = rpmVerifySignature(dig, buf);
switch (rc) {
case RPMRC_OK: /* Signature is OK. */
- rpmMessage(RPMMESS_DEBUG, "%s: %s", fn, buf);
+ rpmlog(RPMLOG_DEBUG, "%s: %s", fn, buf);
break;
case RPMRC_NOTTRUSTED: /* Signature is OK, but key is not trusted. */
case RPMRC_NOKEY: /* Public key is unavailable. */
/* XXX Print NOKEY/NOTTRUSTED warning only once. */
- { int lvl = (pgpStashKeyid(dig) ? RPMMESS_DEBUG : RPMMESS_WARNING);
- rpmMessage(lvl, "%s: %s", fn, buf);
+ { int lvl = (pgpStashKeyid(dig) ? RPMLOG_DEBUG : RPMLOG_WARNING);
+ rpmlog(lvl, "%s: %s", fn, buf);
} break;
case RPMRC_NOTFOUND: /* Signature is unknown type. */
- rpmMessage(RPMMESS_WARNING, "%s: %s", fn, buf);
+ rpmlog(RPMLOG_WARNING, "%s: %s", fn, buf);
break;
default:
case RPMRC_FAIL: /* Signature does not verify. */
- rpmMessage(RPMMESS_ERROR, "%s: %s", fn, buf);
+ rpmlog(RPMLOG_ERR, "%s: %s", fn, buf);
break;
}
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/poptALL.c
============================================================================
$ cvs diff -u -r2.45 -r2.46 poptALL.c
--- rpm/lib/poptALL.c 30 Sep 2007 20:38:25 -0000 2.45
+++ rpm/lib/poptALL.c 11 Oct 2007 19:44:22 -0000 2.46
@@ -206,7 +206,7 @@
if (opt->arg == NULL)
switch (opt->val) {
case 'q':
- rpmSetVerbosity(RPMMESS_QUIET);
+ rpmSetVerbosity(RPMLOG_WARNING);
break;
case 'v':
rpmIncreaseVerbosity();
@@ -574,7 +574,7 @@
(void) textdomain(PACKAGE);
#endif
- rpmSetVerbosity(RPMMESS_NORMAL);
+ rpmSetVerbosity(RPMLOG_NOTICE);
if (optionsTable == NULL) {
/* Read rpm configuration (if not already read). */
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/poptI.c
============================================================================
$ cvs diff -u -r2.37 -r2.38 poptI.c
--- rpm/lib/poptI.c 30 Sep 2007 20:38:25 -0000 2.37
+++ rpm/lib/poptI.c 11 Oct 2007 19:44:22 -0000 2.38
@@ -32,7 +32,7 @@
/**
* Print a message and exit.
- * @todo (CLI embedding) Use rpmMessage/rpmlog instead of fprintf, remove exit.
+ * @todo (CLI embedding) Use rpmlog/rpmlog instead of fprintf, remove exit.
* @param desc message
*/
/*@exits@*/
@@ -142,7 +142,7 @@
/*@-moduncon@*/
tid = get_date(arg, NULL);
- rpmMessage(RPMMESS_VERBOSE, _("Rollback goal: %-24.24s (0x%08x)\n"), ctime(&tid), (int)tid);
+ rpmlog(RPMLOG_INFO, _("Rollback goal: %-24.24s (0x%08x)\n"), ctime(&tid), (int)tid);
/*@=moduncon@*/
if (tid == (time_t)-1 || tid == (time_t)0)
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/psm.c
============================================================================
$ cvs diff -u -r2.235 -r2.236 psm.c
--- rpm/lib/psm.c 11 Oct 2007 19:14:37 -0000 2.235
+++ rpm/lib/psm.c 11 Oct 2007 19:44:22 -0000 2.236
@@ -444,7 +444,7 @@
msecs = psm->sq.op.usecs/1000;
(void) rpmswAdd(rpmtsOp(ts, RPMTS_OP_SCRIPTLETS), &psm->sq.op);
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
D_("%s: waitpid(%d) rc %d status %x secs %u.%03u\n"),
psm->stepName, (unsigned)psm->sq.child,
(unsigned)psm->sq.reaped, psm->sq.status,
@@ -637,7 +637,7 @@
if (progArgv && strcmp(progArgv[0], "<lua>") == 0) {
#ifdef WITH_LUA
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
D_("%s: %s(%s) running <lua> scriptlet.\n"),
psm->stepName, tag2sln(psm->scriptTag), NVRA);
rc = runLuaScript(psm, h, sln, progArgc, progArgv,
@@ -653,7 +653,7 @@
*/
if (ldconfig_path && progArgv != NULL && psm->unorderedSuccessor) {
if (ldconfig_done && !strcmp(progArgv[0], ldconfig_path)) {
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
D_("%s: %s(%s) skipping redundant \"%s\".\n"),
psm->stepName, tag2sln(psm->scriptTag), NVRA,
progArgv[0]);
@@ -662,7 +662,7 @@
}
}
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
D_("%s: %s(%s) %ssynchronous scriptlet start\n"),
psm->stepName, tag2sln(psm->scriptTag), NVRA,
(psm->unorderedSuccessor ? "a" : ""));
@@ -774,7 +774,7 @@
flag = fcntl(fdno, F_GETFD);
if (flag == -1 || (flag & FD_CLOEXEC))
continue;
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
D_("%s: %s(%s)\tfdno(%d) missing FD_CLOEXEC\n"),
psm->stepName, sln, NVRA,
fdno);
@@ -829,7 +829,7 @@
/*@=modobserver@*/
}
xx = Chdir("/");
- rpmMessage(RPMMESS_DEBUG, D_("%s: %s(%s)\texecv(%s) pid %d\n"),
+ rpmlog(RPMLOG_DEBUG, D_("%s: %s(%s)\texecv(%s) pid %d\n"),
psm->stepName, sln, NVRA,
argv[0], (unsigned)getpid());
@@ -1519,7 +1519,7 @@
case PSM_UNKNOWN:
break;
case PSM_INIT:
- rpmMessage(RPMMESS_DEBUG, D_("%s: %s has %d files, test = %d\n"),
+ rpmlog(RPMLOG_DEBUG, D_("%s: %s has %d files, test = %d\n"),
psm->stepName, rpmteNEVR(psm->te),
rpmfiFC(fi), (rpmtsFlags(ts) & RPMTRANS_FLAG_TEST));
@@ -2070,7 +2070,7 @@
if (psm->goal == PSM_PKGSAVE) {
if (!rc && ts && ts->notify == NULL) {
- rpmMessage(RPMMESS_VERBOSE, _("Wrote: %s\n"),
+ rpmlog(RPMLOG_INFO, _("Wrote: %s\n"),
(psm->pkgURL ? psm->pkgURL : "???"));
}
}
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/query.c
============================================================================
$ cvs diff -u -r2.186 -r2.187 query.c
--- rpm/lib/query.c 11 Oct 2007 19:14:37 -0000 2.186
+++ rpm/lib/query.c 11 Oct 2007 19:44:22 -0000 2.187
@@ -136,7 +136,7 @@
*te++ = '\n';
*te = '\0';
}
- rpmMessage(RPMMESS_NORMAL, "%s", t);
+ rpmlog(RPMLOG_NOTICE, "%s", t);
te = t;
*t = '\0';
}
@@ -688,7 +688,7 @@
rpmlog(RPMLOG_ERR, _("invalid package number: %s\n"), arg);
return 1;
}
- rpmMessage(RPMMESS_DEBUG, D_("package record number: %u\n"), recOffset);
+ rpmlog(RPMLOG_DEBUG, D_("package record number: %u\n"), recOffset);
qva->qva_mi = rpmtsInitIterator(ts, RPMDBI_PACKAGES, &recOffset, sizeof(recOffset));
if (qva->qva_mi == NULL) {
rpmlog(RPMLOG_ERR,
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/rpmchecksig.c
============================================================================
$ cvs diff -u -r1.151 -r1.152 rpmchecksig.c
--- rpm/lib/rpmchecksig.c 11 Oct 2007 19:14:37 -0000 1.151
+++ rpm/lib/rpmchecksig.c 11 Oct 2007 19:44:22 -0000 1.152
@@ -355,7 +355,7 @@
/* If same signer, skip resigning the package. */
if (!memcmp(oldsignid, newsignid, sizeof(oldsignid))) {
- rpmMessage(RPMMESS_WARNING,
+ rpmlog(RPMLOG_WARNING,
_("%s: was already signed by key ID %s, skipping\n"),
fn, pgpHexStr(newsignid+4, sizeof(newsignid)-4));
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/rpmds.c
============================================================================
$ cvs diff -u -r2.67 -r2.68 rpmds.c
--- rpm/lib/rpmds.c 6 Oct 2007 16:50:03 -0000 2.67
+++ rpm/lib/rpmds.c 11 Oct 2007 19:44:22 -0000 2.68
@@ -873,7 +873,7 @@
if (!(ds->Type != NULL && ds->DNEVR != NULL))
return;
- rpmMessage(RPMMESS_DEBUG, "%9s: %-45s %-s %s\n", ds->Type,
+ rpmlog(RPMLOG_DEBUG, "%9s: %-45s %-s %s\n", ds->Type,
(!strcmp(ds->DNEVR, "cached") ? ds->DNEVR : ds->DNEVR+2),
(rc ? _("NO ") : _("YES")),
(where != NULL ? where : ""));
@@ -3600,8 +3600,8 @@
/*@i@*/ sense = EVRcmp(a->E, b->E);
else if (a->E && *a->E && atol(a->E) > 0) {
if (!B->nopromote) {
- int lvl = (_rpmds_unspecified_epoch_noise ? RPMMESS_WARNING : RPMMESS_DEBUG);
- rpmMessage(lvl, _("The \"B\" dependency needs an epoch (assuming same epoch as \"A\")\n\tA = \"%s\"\tB = \"%s\"\n"),
+ int lvl = (_rpmds_unspecified_epoch_noise ? RPMLOG_WARNING : RPMLOG_DEBUG);
+ rpmlog(lvl, _("The \"B\" dependency needs an epoch (assuming same epoch as \"A\")\n\tA = \"%s\"\tB = \"%s\"\n"),
aDepend, bDepend);
sense = 0;
} else
@@ -3635,7 +3635,7 @@
exit:
if (_noisy_range_comparison_debug_message)
- rpmMessage(RPMMESS_DEBUG, _(" %s A %s\tB %s\n"),
+ rpmlog(RPMLOG_DEBUG, _(" %s A %s\tB %s\n"),
(result ? _("YES") : _("NO ")), aDepend, bDepend);
aDepend = _free(aDepend);
bDepend = _free(bDepend);
@@ -3657,7 +3657,7 @@
if (EVR == NULL) EVR = "?EVR?";
if (DNEVR == NULL) DNEVR = "? ?N? ?OP? ?EVR?";
- rpmMessage(RPMMESS_DEBUG, D_("package %s has unsatisfied %s: %s\n"),
+ rpmlog(RPMLOG_DEBUG, D_("package %s has unsatisfied %s: %s\n"),
pkgNEVR, ds->Type, DNEVR+2);
switch ((unsigned)DNEVR[0]) {
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/rpmfc.c
============================================================================
$ cvs diff -u -r1.20 -r1.21 rpmfc.c
--- rpm/lib/rpmfc.c 11 Oct 2007 19:14:37 -0000 1.20
+++ rpm/lib/rpmfc.c 11 Oct 2007 19:44:22 -0000 1.21
@@ -90,7 +90,7 @@
(void) Chdir(dir);
}
- rpmMessage(RPMMESS_DEBUG, D_("\texecv(%s) pid %d\n"),
+ rpmlog(RPMLOG_DEBUG, D_("\texecv(%s) pid %d\n"),
argv[0], (unsigned)getpid());
unsetenv("MALLOC_CHECK_");
@@ -184,7 +184,7 @@
/* Collect status from prog */
reaped = waitpid(child, &status, 0);
- rpmMessage(RPMMESS_DEBUG, D_("\twaitpid(%d) rc %d status %x\n"),
+ rpmlog(RPMLOG_DEBUG, D_("\twaitpid(%d) rc %d status %x\n"),
(unsigned)child, (unsigned)reaped, status);
if (failNonZero && (!WIFEXITED(status) || WEXITSTATUS(status))) {
@@ -1059,7 +1059,7 @@
}
se = ftype;
- rpmMessage(RPMMESS_DEBUG, "%s: %s\n", s, se);
+ rpmlog(RPMLOG_DEBUG, "%s: %s\n", s, se);
/* Save the path. */
xx = argvAdd(&fc->fn, s);
@@ -1200,15 +1200,15 @@
if (!((Flags & dm->mask) ^ dm->xor))
/*@innercontinue@*/ continue;
if (bingo == 0) {
- rpmMessage(RPMMESS_NORMAL, "%s:", (dm->msg ? dm->msg : ""));
+ rpmlog(RPMLOG_NOTICE, "%s:", (dm->msg ? dm->msg : ""));
bingo = 1;
}
if ((DNEVR = rpmdsDNEVR(ds)) == NULL)
/*@innercontinue@*/ continue; /* XXX can't happen */
- rpmMessage(RPMMESS_NORMAL, " %s", DNEVR+2);
+ rpmlog(RPMLOG_NOTICE, " %s", DNEVR+2);
}
if (bingo)
- rpmMessage(RPMMESS_NORMAL, "\n");
+ rpmlog(RPMLOG_NOTICE, "\n");
}
ds = rpmdsFree(ds);
}
@@ -1266,7 +1266,7 @@
continue;
s = rpmExpand(dm->argv[0], NULL);
- rpmMessage(RPMMESS_NORMAL, _("Finding %s: %s\n"), dm->msg,
+ rpmlog(RPMLOG_NOTICE, _("Finding %s: %s\n"), dm->msg,
(s ? s : ""));
s = _free(s);
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/rpmfi.c
============================================================================
$ cvs diff -u -r2.80 -r2.81 rpmfi.c
--- rpm/lib/rpmfi.c 6 Oct 2007 21:33:48 -0000 2.80
+++ rpm/lib/rpmfi.c 11 Oct 2007 19:44:22 -0000 2.81
@@ -574,7 +574,7 @@
* package has marked it as missingok, or allfiles is requested.
*/
if (skipMissing && (newFlags & RPMFILE_MISSINGOK)) {
- rpmMessage(RPMMESS_DEBUG, D_("%s skipped due to missingok flag\n"),
+ rpmlog(RPMLOG_DEBUG, D_("%s skipped due to missingok flag\n"),
fn);
return FA_SKIP;
} else {
@@ -821,14 +821,14 @@
if (!_printed) {
_printed = 1;
- rpmMessage(RPMMESS_DEBUG, D_("========== relocations\n"));
+ rpmlog(RPMLOG_DEBUG, D_("========== relocations\n"));
for (i = 0; i < numRelocations; i++) {
if (relocations[i].oldPath == NULL) continue; /* XXX can't happen */
if (relocations[i].newPath == NULL)
- rpmMessage(RPMMESS_DEBUG, D_("%5d exclude %s\n"),
+ rpmlog(RPMLOG_DEBUG, D_("%5d exclude %s\n"),
i, relocations[i].oldPath);
else
- rpmMessage(RPMMESS_DEBUG, D_("%5d relocate %s -> %s\n"),
+ rpmlog(RPMLOG_DEBUG, D_("%5d relocate %s -> %s\n"),
i, relocations[i].oldPath, relocations[i].newPath);
}
}
@@ -960,7 +960,7 @@
}
if (actions) {
actions[i] = FA_SKIPNSTATE;
- rpmMessage(RPMMESS_DEBUG, D_("excluding %s %s\n"),
+ rpmlog(RPMLOG_DEBUG, D_("excluding %s %s\n"),
rpmfiFtstring(ft), fn);
}
continue;
@@ -970,7 +970,7 @@
if (fnlen != len) continue;
if (actions)
- rpmMessage(RPMMESS_DEBUG, D_("relocating %s to %s\n"),
+ rpmlog(RPMLOG_DEBUG, D_("relocating %s to %s\n"),
fn, relocations[j].newPath);
nrelocated++;
@@ -1061,7 +1061,7 @@
t[slen+1] = '\0';
if (actions)
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
D_("relocating directory %s to %s\n"), dirNames[i], t);
dirNames[i] = t;
nrelocated++;
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/rpminstall.c
============================================================================
$ cvs diff -u -r1.167 -r1.168 rpminstall.c
--- rpm/lib/rpminstall.c 11 Oct 2007 19:14:37 -0000 1.167
+++ rpm/lib/rpminstall.c 11 Oct 2007 19:44:22 -0000 1.168
@@ -262,7 +262,7 @@
if (rc && rpmpsNumProblems(ps) > 0) {
if (msg)
- rpmMessage(RPMMESS_ERROR, "%s:\n", msg);
+ rpmlog(RPMLOG_ERR, "%s:\n", msg);
rpmpsPrint(NULL, ps);
}
ps = rpmpsFree(ps);
@@ -275,11 +275,11 @@
const char * s;
int i;
- rpmMessage(RPMMESS_NORMAL, _(" Suggested resolutions:\n"));
+ rpmlog(RPMLOG_NOTICE, _(" Suggested resolutions:\n"));
for (i = 0; i < ts->nsuggests && (s = ts->suggests[i]) != NULL;
ts->suggests[i++] = s = _free(s))
{
- rpmMessage(RPMMESS_NORMAL, "\t%s\n", s);
+ rpmlog(RPMLOG_NOTICE, "\t%s\n", s);
}
ts->suggests = _free(ts->suggests);
}
@@ -337,7 +337,7 @@
if (rpmExpandNumeric("%{?_rollback_transaction_on_failure}")) {
if (ia->arbtid) {
time_t ttid = (time_t)ia->arbtid;
- rpmMessage(RPMMESS_DEBUG, D_("Autorollback Goal: %-24.24s (0x%08x)\n"),
+ rpmlog(RPMLOG_DEBUG, D_("Autorollback Goal: %-24.24s (0x%08x)\n"),
ctime(&ttid), ia->arbtid);
rpmtsSetARBGoal(ts, ia->arbtid);
}
@@ -383,7 +383,7 @@
ts->suggests[ts->nsuggests] = _free(ts->suggests[ts->nsuggests]);
}
ts->suggests = _free(ts->suggests);
- rpmMessage(RPMMESS_DEBUG, D_("Adding goal: %s\n"), fileURL);
+ rpmlog(RPMLOG_DEBUG, D_("Adding goal: %s\n"), fileURL);
pkgURL[pkgx] = fileURL;
fileURL = NULL;
pkgx++;
@@ -427,7 +427,7 @@
} else {
const char * NVRA = NULL;
xx = headerGetExtension(h, RPMTAG_NVRA, NULL, &NVRA, NULL);
- rpmMessage(RPMMESS_ERROR,
+ rpmlog(RPMLOG_ERR,
_("package %s is not relocatable\n"), NVRA);
NVRA = _free(NVRA);
numFailed++;
@@ -540,7 +540,7 @@
if (rpmExpandNumeric("%{?_rollback_transaction_on_failure}")) {
if (ia->arbtid) {
time_t ttid = (time_t)ia->arbtid;
- rpmMessage(RPMMESS_DEBUG, D_("Autorollback Goal: %-24.24s (0x%08x)\n"),
+ rpmlog(RPMLOG_DEBUG, D_("Autorollback Goal: %-24.24s (0x%08x)\n"),
ctime(&ttid), ia->arbtid);
rpmtsSetARBGoal(ts, ia->arbtid);
}
@@ -562,7 +562,7 @@
/* XXX HACK to get rpmdbFindByLabel out of the API */
mi = rpmtsInitIterator(ts, RPMDBI_LABEL, *arg, 0);
if (mi == NULL) {
- rpmMessage(RPMMESS_ERROR, _("package %s is not installed\n"), *arg);
+ rpmlog(RPMLOG_ERR, _("package %s is not installed\n"), *arg);
numFailed++;
} else {
Header h; /* XXX iterator owns the reference */
@@ -571,7 +571,7 @@
unsigned int recOffset = rpmdbGetIteratorOffset(mi);
if (!(count++ == 0 || (ia->installInterfaceFlags & INSTALL_ALLMATCHES))) {
- rpmMessage(RPMMESS_ERROR, _("\"%s\" specifies multiple packages\n"),
+ rpmlog(RPMLOG_ERR, _("\"%s\" specifies multiple packages\n"),
*arg);
numFailed++;
/*@innerbreak@*/ break;
@@ -596,7 +596,7 @@
ps = rpmtsProblems(ts);
if (!stopUninstall && rpmpsNumProblems(ps) > 0) {
- rpmMessage(RPMMESS_ERROR, _("Failed dependencies:\n"));
+ rpmlog(RPMLOG_ERR, _("Failed dependencies:\n"));
rpmpsPrint(NULL, ps);
numFailed += numPackages;
stopUninstall = 1;
@@ -639,7 +639,7 @@
fd = Fopen(arg, "r.fdio");
if (fd == NULL || Ferror(fd)) {
- rpmMessage(RPMMESS_ERROR, _("cannot open %s: %s\n"), arg, Fstrerror(fd));
+ rpmlog(RPMLOG_ERR, _("cannot open %s: %s\n"), arg, Fstrerror(fd));
if (fd != NULL) (void) Fclose(fd);
return 1;
}
@@ -655,7 +655,7 @@
ovsflags = rpmtsSetVSFlags(ts, ovsflags);
}
if (rc != 0) {
- rpmMessage(RPMMESS_ERROR, _("%s cannot be installed\n"), arg);
+ rpmlog(RPMLOG_ERR, _("%s cannot be installed\n"), arg);
/*@-unqualifiedtrans@*/
if (specFilePtr && *specFilePtr)
*specFilePtr = _free(*specFilePtr);
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/rpmlock.c
============================================================================
$ cvs diff -u -r2.15 -r2.16 rpmlock.c
--- rpm/lib/rpmlock.c 6 Oct 2007 21:33:48 -0000 2.15
+++ rpm/lib/rpmlock.c 11 Oct 2007 19:44:22 -0000 2.16
@@ -145,16 +145,16 @@
rc = rpmlock_new(rootDir, &lock);
if (rc) {
if (rpmlock_path != NULL && strcmp(rpmlock_path, rootDir))
- rpmMessage(RPMMESS_ERROR,
+ rpmlog(RPMLOG_ERR,
_("can't create transaction lock on %s\n"), rpmlock_path);
} else if (lock != NULL) {
if (!rpmlock_acquire(lock, RPMLOCK_WRITE)) {
if (lock->omode & RPMLOCK_WRITE)
- rpmMessage(RPMMESS_WARNING,
+ rpmlog(RPMLOG_WARNING,
_("waiting for transaction lock on %s\n"), rpmlock_path);
if (!rpmlock_acquire(lock, RPMLOCK_WRITE|RPMLOCK_WAIT)) {
if (rpmlock_path != NULL && strcmp(rpmlock_path, rootDir))
- rpmMessage(RPMMESS_ERROR,
+ rpmlog(RPMLOG_ERR,
_("can't create transaction lock on %s\n"), rpmlock_path);
lock = rpmlock_free(lock);
}
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/rpmrollback.c
============================================================================
$ cvs diff -u -r1.15 -r1.16 rpmrollback.c
--- rpm/lib/rpmrollback.c 11 Oct 2007 19:14:37 -0000 1.15
+++ rpm/lib/rpmrollback.c 11 Oct 2007 19:44:22 -0000 1.16
@@ -343,7 +343,7 @@
}
erase:
- rpmMessage(RPMMESS_DEBUG, D_("\t--- erase h#%u\n"), ip->instance);
+ rpmlog(RPMLOG_DEBUG, D_("\t--- erase h#%u\n"), ip->instance);
rc = rpmtsAddEraseElement(ts, ip->h, ip->instance);
if (rc != 0)
@@ -488,7 +488,7 @@
excludedTID++) {
if (thistid == *excludedTID) {
time_t ttid = (time_t)thistid;
- rpmMessage(RPMMESS_NORMAL,
+ rpmlog(RPMLOG_NOTICE,
_("Excluding TID from rollback: %-24.24s (0x%08x)\n"),
ctime(&ttid), thistid);
excluded = 1;
@@ -528,7 +528,7 @@
*/
while (rp != NULL && rp->val.u32 == thistid) {
if (!rp->done) {
- rpmMessage(RPMMESS_DEBUG, D_("\t+++ install %s\n"),
+ rpmlog(RPMLOG_DEBUG, D_("\t+++ install %s\n"),
(rp->key ? rp->key : "???"));
/*@-abstract@*/
@@ -598,7 +598,7 @@
break;
tid = (time_t)thistid;
- rpmMessage(RPMMESS_NORMAL,
+ rpmlog(RPMLOG_NOTICE,
_("Rollback packages (+%d/-%d) to %-24.24s (0x%08x):\n"),
numAdded, numRemoved, ctime(&tid), thistid);
@@ -625,14 +625,14 @@
/* Remove repackaged packages after successful reinstall. */
if (rtids && !rpmIsDebug()) {
int i;
- rpmMessage(RPMMESS_NORMAL, _("Cleaning up repackaged packages:\n"));
+ rpmlog(RPMLOG_NOTICE, _("Cleaning up repackaged packages:\n"));
if (rtids->idt)
for (i = 0; i < rtids->nidt; i++) {
IDT rrp = rtids->idt + i;
if (rrp->val.u32 != thistid)
/*@innercontinue@*/ continue;
if (rrp->key) { /* XXX can't happen */
- rpmMessage(RPMMESS_NORMAL, _("\tRemoving %s:\n"), rrp->key);
+ rpmlog(RPMLOG_NOTICE, _("\tRemoving %s:\n"), rrp->key);
(void) unlink(rrp->key); /* XXX: Should check rc??? */
}
}
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/rpmts.c
============================================================================
$ cvs diff -u -r2.106 -r2.107 rpmts.c
--- rpm/lib/rpmts.c 11 Oct 2007 19:14:37 -0000 2.106
+++ rpm/lib/rpmts.c 11 Oct 2007 19:44:22 -0000 2.107
@@ -123,7 +123,7 @@
if (rc) {
const char * dn;
dn = rpmGetPath(ts->rootDir, "%{_dbpath}", NULL);
- rpmMessage(RPMMESS_ERROR,
+ rpmlog(RPMLOG_ERR,
_("cannot open Packages database in %s\n"), dn);
dn = _free(dn);
}
@@ -277,7 +277,7 @@
if (rc) {
const char * dn;
dn = rpmGetPath(ts->rootDir, "%{_dbpath}", NULL);
- rpmMessage(RPMMESS_WARNING,
+ rpmlog(RPMLOG_WARNING,
_("cannot open Solve database in %s\n"), dn);
dn = _free(dn);
/* XXX only try to open the solvedb once. */
@@ -424,7 +424,7 @@
if (h != NULL &&
!rpmtsAddInstallElement(ts, h, (fnpyKey)str, 1, NULL))
{
- rpmMessage(RPMMESS_DEBUG, D_("Adding: %s\n"), str);
+ rpmlog(RPMLOG_DEBUG, D_("Adding: %s\n"), str);
rc = -1; /* XXX restart unsatisfiedDepends() */
break;
}
@@ -435,7 +435,7 @@
goto exit;
}
- rpmMessage(RPMMESS_DEBUG, D_("Suggesting: %s\n"), str);
+ rpmlog(RPMLOG_DEBUG, D_("Suggesting: %s\n"), str);
/* If suggestion is already present, don't bother. */
if (ts->suggests != NULL && ts->nsuggests > 0) {
if (bsearch(&str, ts->suggests, ts->nsuggests,
@@ -906,8 +906,8 @@
if (ts->filesystems != NULL)
return 0;
- rpmMessage(RPMMESS_DEBUG, D_("mounted filesystems:\n"));
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG, D_("mounted filesystems:\n"));
+ rpmlog(RPMLOG_DEBUG,
D_(" i dev bsize bavail iavail mount point\n"));
rc = rpmGetFilesystemList(&ts->filesystems, &ts->filesystemCount);
@@ -996,7 +996,7 @@
#if !defined(ST_RDONLY)
#define ST_RDONLY 1
#endif
- rpmMessage(RPMMESS_DEBUG, "%5d 0x%08x %8u %12ld %12ld %s %s\n",
+ rpmlog(RPMLOG_DEBUG, "%5d 0x%08x %8u %12ld %12ld %s %s\n",
i, (unsigned) dsi->dev, (unsigned) dsi->f_bsize,
(signed long) dsi->f_bavail, (signed long) dsi->f_favail,
((dsi->f_flag & ST_RDONLY) ? "ro" : "rw"),
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/transaction.c
============================================================================
$ cvs diff -u -r1.336 -r1.337 transaction.c
--- rpm/lib/transaction.c 6 Oct 2007 21:33:48 -0000 1.336
+++ rpm/lib/transaction.c 11 Oct 2007 19:44:22 -0000 1.337
@@ -856,7 +856,7 @@
/*@innercontinue@*/ continue;
if (strncmp(fbn, bn, bnlen))
/*@innercontinue@*/ continue;
- rpmMessage(RPMMESS_DEBUG, D_("excluding directory %s\n"), dn);
+ rpmlog(RPMLOG_DEBUG, D_("excluding directory %s\n"), dn);
fi->actions[i] = FA_SKIPNSTATE;
/*@innerbreak@*/ break;
}
@@ -979,7 +979,7 @@
rpmtsGetTid(rbts),
te->u.removed.dboffset, NULL);
if (rc != RPMRC_OK) {
- rpmMessage(RPMMESS_ERROR, _("rpmdb erase failed. NEVRA: %s\n"),
+ rpmlog(RPMLOG_ERR, _("rpmdb erase failed. NEVRA: %s\n"),
rpmteNEVRA(te));
break;
}
@@ -997,7 +997,7 @@
rpmtsEmpty(rbts);
ttid = (time_t)arbgoal;
- rpmMessage(RPMMESS_NORMAL, _("Rollback to %-24.24s (0x%08x)\n"),
+ rpmlog(RPMLOG_NOTICE, _("Rollback to %-24.24s (0x%08x)\n"),
ctime(&ttid), arbgoal);
/* Set the verify signature flags:
@@ -1143,7 +1143,7 @@
/* XXX programmer error segfault avoidance. */
if (rpmtsNElements(ts) <= 0) {
- rpmMessage(RPMMESS_ERROR,
+ rpmlog(RPMLOG_ERR,
_("Invalid number of transaction elements.\n"));
return -1;
}
@@ -1224,7 +1224,7 @@
* - count files.
*/
-rpmMessage(RPMMESS_DEBUG, D_("sanity checking %d elements\n"), rpmtsNElements(ts));
+rpmlog(RPMLOG_DEBUG, D_("sanity checking %d elements\n"), rpmtsNElements(ts));
ps = rpmtsProblems(ts);
/* The ordering doesn't matter here */
pi = rpmtsiInit(ts);
@@ -1299,7 +1299,7 @@
|| (rpmpsNumProblems(ts->probs) &&
(okProbs == NULL || rpmpsTrim(ts->probs, okProbs)))))
{
- rpmMessage(RPMMESS_DEBUG, D_("running pre-transaction scripts\n"));
+ rpmlog(RPMLOG_DEBUG, D_("running pre-transaction scripts\n"));
pi = rpmtsiInit(ts);
while ((p = rpmtsiNext(pi, TR_ADDED)) != NULL) {
if (p->isSource) continue;
@@ -1373,7 +1373,7 @@
* calling fpLookupList only once. I'm not sure that the speedup is
* worth the trouble though.
*/
-rpmMessage(RPMMESS_DEBUG, D_("computing %d file fingerprints\n"), totalFileCount);
+rpmlog(RPMLOG_DEBUG, D_("computing %d file fingerprints\n"), totalFileCount);
numAdded = numRemoved = 0;
pi = rpmtsiInit(ts);
@@ -1460,7 +1460,7 @@
/* ===============================================
* Compute file disposition for each package in transaction set.
*/
-rpmMessage(RPMMESS_DEBUG, D_("computing file dispositions\n"));
+rpmlog(RPMLOG_DEBUG, D_("computing file dispositions\n"));
ps = rpmtsProblems(ts);
pi = rpmtsiInit(ts);
/*@-nullpass@*/
@@ -1736,7 +1736,7 @@
pkgKey = rpmteAddedKey(p);
- rpmMessage(RPMMESS_DEBUG, "========== +++ %s %s-%s 0x%x\n",
+ rpmlog(RPMLOG_DEBUG, "========== +++ %s %s-%s 0x%x\n",
rpmteNEVR(p), rpmteA(p), rpmteO(p), rpmteColor(p));
p->h = NULL;
@@ -1839,7 +1839,7 @@
case TR_REMOVED:
(void) rpmswEnter(rpmtsOp(ts, RPMTS_OP_ERASE), 0);
- rpmMessage(RPMMESS_DEBUG, "========== --- %s %s-%s 0x%x\n",
+ rpmlog(RPMLOG_DEBUG, "========== --- %s %s-%s 0x%x\n",
rpmteNEVR(p), rpmteA(p), rpmteO(p), rpmteColor(p));
/* If linked element install failed, then don't erase. */
@@ -1880,7 +1880,7 @@
pi = rpmtsiFree(pi);
if (!(rpmtsFlags(ts) & RPMTRANS_FLAG_TEST)) {
- rpmMessage(RPMMESS_DEBUG, D_("running post-transaction scripts\n"));
+ rpmlog(RPMLOG_DEBUG, D_("running post-transaction scripts\n"));
pi = rpmtsiInit(ts);
while ((p = rpmtsiNext(pi, TR_ADDED)) != NULL) {
int haspostscript;
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/verify.c
============================================================================
$ cvs diff -u -r2.169 -r2.170 verify.c
--- rpm/lib/verify.c 30 Sep 2007 20:38:26 -0000 2.169
+++ rpm/lib/verify.c 11 Oct 2007 19:44:22 -0000 2.170
@@ -358,7 +358,7 @@
if (te > t) {
*te++ = '\n';
*te = '\0';
- rpmMessage(RPMMESS_NORMAL, "%s", t);
+ rpmlog(RPMLOG_NOTICE, "%s", t);
te = t = buf;
*t = '\0';
}
@@ -434,7 +434,7 @@
if (te > t) {
*te++ = '\n';
*te = '\0';
- rpmMessage(RPMMESS_NORMAL, "%s", t);
+ rpmlog(RPMLOG_NOTICE, "%s", t);
te = t;
*t = '\0';
}
@@ .
patch -p0 <<'@@ .'
Index: rpm/rpmdb/db3.c
============================================================================
$ cvs diff -u -r1.75 -r1.76 db3.c
--- rpm/rpmdb/db3.c 11 Oct 2007 13:04:28 -0000 1.75
+++ rpm/rpmdb/db3.c 11 Oct 2007 19:44:24 -0000 1.76
@@ -208,7 +208,7 @@
rc = cvtdberr(dbi, "dbenv->close", rc, _debug);
if (dbfile)
- rpmMessage(RPMMESS_DEBUG, D_("closed db environment %s/%s\n"),
+ rpmlog(RPMLOG_DEBUG, D_("closed db environment %s/%s\n"),
dbhome, dbfile);
if (rpmdb->db_remove_env) {
@@ -227,7 +227,7 @@
xx = cvtdberr(dbi, "dbenv->remove", xx, _debug);
if (dbfile)
- rpmMessage(RPMMESS_DEBUG, D_("removed db environment %s/%s\n"),
+ rpmlog(RPMLOG_DEBUG, D_("removed db environment %s/%s\n"),
dbhome, dbfile);
}
@@ -306,7 +306,7 @@
if (eflags & DB_JOINENV) eflags &= DB_JOINENV;
if (dbfile)
- rpmMessage(RPMMESS_DEBUG, D_("opening db environment %s/%s %s\n"),
+ rpmlog(RPMLOG_DEBUG, D_("opening db environment %s/%s %s\n"),
dbhome, dbfile, prDbiOpenFlags(eflags, 1));
/* XXX Can't do RPC w/o host. */
@@ -977,7 +977,7 @@
rc = cvtdberr(dbi, "db->close", rc, _printit);
db = dbi->dbi_db = NULL;
- rpmMessage(RPMMESS_DEBUG, D_("closed db index %s/%s\n"),
+ rpmlog(RPMLOG_DEBUG, D_("closed db index %s/%s\n"),
dbhome, (dbfile ? dbfile : mapTagName(dbi->dbi_rpmtag)));
}
@@ -1049,7 +1049,7 @@
rc = db->verify(db, dbf, NULL, NULL, flags);
rc = cvtdberr(dbi, "db->verify", rc, _debug);
- rpmMessage(RPMMESS_DEBUG, D_("verified db index %s/%s\n"),
+ rpmlog(RPMLOG_DEBUG, D_("verified db index %s/%s\n"),
(dbhome ? dbhome : ""),
(dbfile ? dbfile : mapTagName(dbi->dbi_rpmtag)));
@@ -1344,7 +1344,7 @@
/*@=mods@*/
}
- rpmMessage(RPMMESS_DEBUG, D_("opening db index %s/%s %s mode=0x%x\n"),
+ rpmlog(RPMLOG_DEBUG, D_("opening db index %s/%s %s mode=0x%x\n"),
dbhome, (dbfile ? dbfile : mapTagName(dbi->dbi_rpmtag)),
prDbiOpenFlags(oflags, 0), dbi->dbi_mode);
@@ -1586,7 +1586,7 @@
? _("exclusive") : _("shared")),
dbhome, (dbfile ? dbfile : ""));
} else if (dbfile) {
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
D_("locked db index %s/%s\n"),
dbhome, dbfile);
}
@@ .
patch -p0 <<'@@ .'
Index: rpm/rpmdb/pkgio.c
============================================================================
$ cvs diff -u -r1.13 -r1.14 pkgio.c
--- rpm/rpmdb/pkgio.c 7 Oct 2007 15:59:46 -0000 1.13
+++ rpm/rpmdb/pkgio.c 11 Oct 2007 19:44:24 -0000 1.14
@@ -257,7 +257,7 @@
memcpy(ts->pksignid, pubp->signid, sizeof(ts->pksignid));
if (pubkeysource)
- rpmMessage(RPMMESS_DEBUG, "========== %s pubkey id %08x %08x (%s)\n",
+ rpmlog(RPMLOG_DEBUG, "========== %s pubkey id %08x %08x (%s)\n",
(sigp->pubkey_algo == PGPPUBKEYALGO_DSA ? "DSA" :
(sigp->pubkey_algo == PGPPUBKEYALGO_RSA ? "RSA" : "???")),
pgpGrab(sigp->signid, 4), pgpGrab(sigp->signid+4, 4),
@@ -504,7 +504,7 @@
if (Fwrite(zero, sizeof(zero[0]), pad, fd) != pad)
rc = RPMRC_FAIL;
}
- rpmMessage(RPMMESS_DEBUG, D_("Signature: size(%d)+pad(%d)\n"), sigSize, pad);
+ rpmlog(RPMLOG_DEBUG, D_("Signature: size(%d)+pad(%d)\n"), sigSize, pad);
return rc;
}
@@ -535,11 +535,11 @@
return RPMRC_FAIL;
expected = nl + siglen + pad + datalen;
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
D_("Expected size: %12lu = lead(%u)+sigs(%d)+pad(%d)+data(%lu)\n"),
(unsigned long)expected,
(unsigned)nl, siglen, pad, (unsigned long)datalen);
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
D_(" Actual size: %12lu\n"), (unsigned long)st->st_size);
return RPMRC_OK;
@@ -963,7 +963,7 @@
/* Parse the parameters from the OpenPGP packets that will be needed. */
xx = pgpPrtPkts(sig, info->count, dig, (_print_pkts & rpmIsDebug()));
if (dig->signature.version != 3 && dig->signature.version != 4) {
- rpmMessage(RPMMESS_ERROR,
+ rpmlog(RPMLOG_ERR,
_("skipping header with unverifiable V%u signature\n"),
dig->signature.version);
rpmtsCleanDig(ts);
@@ -1007,7 +1007,7 @@
/* Parse the parameters from the OpenPGP packets that will be needed. */
xx = pgpPrtPkts(sig, info->count, dig, (_print_pkts & rpmIsDebug()));
if (dig->signature.version != 3 && dig->signature.version != 4) {
- rpmMessage(RPMMESS_ERROR,
+ rpmlog(RPMLOG_ERR,
_("skipping header with unverifiable V%u signature\n"),
dig->signature.version);
rpmtsCleanDig(ts);
@@ .
patch -p0 <<'@@ .'
Index: rpm/rpmdb/rpmdb.c
============================================================================
$ cvs diff -u -r1.172 -r1.173 rpmdb.c
--- rpm/rpmdb/rpmdb.c 11 Oct 2007 19:14:41 -0000 1.172
+++ rpm/rpmdb/rpmdb.c 11 Oct 2007 19:44:24 -0000 1.173
@@ -236,7 +236,7 @@
*oe++ = '\0';
rpmtag = tagValue(o);
if (rpmtag < 0) {
- rpmMessage(RPMMESS_WARNING,
+ rpmlog(RPMLOG_WARNING,
_("dbiTagsInit: unrecognized tag name: \"%s\" ignored\n"), o);
continue;
}
@@ -361,7 +361,7 @@
default:
_dbapi = _dbapi_wanted;
if (_dbapi < 0 || _dbapi >= 5 || mydbvecs[_dbapi] == NULL) {
- rpmMessage(RPMMESS_DEBUG, D_("dbiOpen: _dbiapi failed\n"));
+ rpmlog(RPMLOG_DEBUG, D_("dbiOpen: _dbiapi failed\n"));
return NULL;
}
errno = 0;
@@ -780,7 +780,7 @@
if (rpmdbCheckTerminate(0)) {
/*@-abstract@*/ /* sigset_t is abstract type */
- rpmMessage(RPMMESS_DEBUG, D_("Exiting on signal(0x%lx) ...\n"), *((unsigned long *)&rpmsqCaught));
+ rpmlog(RPMLOG_DEBUG, D_("Exiting on signal(0x%lx) ...\n"), *((unsigned long *)&rpmsqCaught));
/*@=abstract@*/
exit(EXIT_FAILURE);
}
@@ -883,12 +883,12 @@
stamp.actime = *iidp;
stamp.modtime = *iidp;
if (!Utime(fn, &stamp))
- rpmMessage(RPMMESS_DEBUG, " +++ %s\n", fn);
+ rpmlog(RPMLOG_DEBUG, " +++ %s\n", fn);
}
}
} else {
if (!Unlink(fn))
- rpmMessage(RPMMESS_DEBUG, " --- %s\n", fn);
+ rpmlog(RPMLOG_DEBUG, " --- %s\n", fn);
}
exit:
@@ -1857,8 +1857,8 @@
assert(data->data != NULL);
rpmrc = headerCheck(mi->mi_ts, data->data, data->size, &msg);
- lvl = (rpmrc == RPMRC_FAIL ? RPMMESS_ERROR : RPMMESS_DEBUG);
- rpmMessage(lvl, "%s h#%8u %s",
+ lvl = (rpmrc == RPMRC_FAIL ? RPMLOG_ERR : RPMLOG_DEBUG);
+ rpmlog(lvl, "%s h#%8u %s",
(rpmrc == RPMRC_FAIL ? _("miFreeHeader: skipping") : "write"),
mi->mi_prevoffset, (msg ? msg : "\n"));
msg = _free(msg);
@@ -2425,8 +2425,8 @@
assert(data->data != NULL);
rpmrc = headerCheck(mi->mi_ts, uh, uhlen, &msg);
- lvl = (rpmrc == RPMRC_FAIL ? RPMMESS_ERROR : RPMMESS_DEBUG);
- rpmMessage(lvl, "%s h#%8u %s",
+ lvl = (rpmrc == RPMRC_FAIL ? RPMLOG_ERR : RPMLOG_DEBUG);
+ rpmlog(lvl, "%s h#%8u %s",
(rpmrc == RPMRC_FAIL ? _("rpmdbNextIterator: skipping") : " read"),
mi->mi_offset, (msg ? msg : "\n"));
msg = _free(msg);
@@ -2808,7 +2808,7 @@
{ hRET_t NVRA;
(void) headerGetExtension(h, RPMTAG_NVRA, NULL, &NVRA, NULL);
- rpmMessage(RPMMESS_DEBUG, " --- h#%8u %s\n", hdrNum, NVRA.str);
+ rpmlog(RPMLOG_DEBUG, " --- h#%8u %s\n", hdrNum, NVRA.str);
NVRA.str = _free(NVRA.str);
}
@@ -2977,11 +2977,11 @@
if (!printed) {
if (he_c == 1 && stringvalued) {
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
D_("removing \"%s\" from %s index.\n"),
(char *)key->data, tagName(dbi->dbi_rpmtag));
} else {
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
D_("removing %d entries from %s index.\n"),
he_c, tagName(dbi->dbi_rpmtag));
}
@@ -3284,8 +3284,8 @@
assert(data->data != NULL);
rpmrc = headerCheck(ts, data->data, data->size, &msg);
- lvl = (rpmrc == RPMRC_FAIL ? RPMMESS_ERROR : RPMMESS_DEBUG);
- rpmMessage(lvl, "%s h#%8u %s",
+ lvl = (rpmrc == RPMRC_FAIL ? RPMLOG_ERR : RPMLOG_DEBUG);
+ rpmlog(lvl, "%s h#%8u %s",
(rpmrc == RPMRC_FAIL ? _("rpmdbAdd: skipping") : " +++"),
hdrNum, (msg ? msg : "\n"));
msg = _free(msg);
@@ -3457,11 +3457,11 @@
if (!printed) {
if (he_c == 1 && stringvalued) {
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
D_("adding \"%s\" to %s index.\n"),
(char *)key->data, tagName(dbi->dbi_rpmtag));
} else {
- rpmMessage(RPMMESS_DEBUG,
+ rpmlog(RPMLOG_DEBUG,
D_("adding %d entries to %s index.\n"),
he_c, tagName(dbi->dbi_rpmtag));
}
@@ -3781,7 +3781,7 @@
if (!rpmioFileExists(ofn)) {
if (rpmioFileExists(nfn)) {
- rpmMessage(RPMMESS_DEBUG, D_("removing file \"%s\"\n"), nfn);
+ rpmlog(RPMLOG_DEBUG, D_("removing file \"%s\"\n"), nfn);
xx = Unlink(nfn);
}
goto bottom;
@@ -3794,8 +3794,8 @@
if (Stat(nfn, nst) < 0 && Stat(ofn, nst) < 0)
goto bottom;
- rpmMessage(RPMMESS_DEBUG, D_("moving file from \"%s\"\n"), ofn);
- rpmMessage(RPMMESS_DEBUG, D_("moving file to \"%s\"\n"), nfn);
+ rpmlog(RPMLOG_DEBUG, D_("moving file from \"%s\"\n"), ofn);
+ rpmlog(RPMLOG_DEBUG, D_("moving file to \"%s\"\n"), nfn);
if ((xx = Rename(ofn, nfn)) != 0) {
rc = 1;
goto bottom;
@@ -3820,12 +3820,12 @@
for (i = 0; i < 16; i++) {
(void) snprintf(osuffix, sizeof("000"), "%03d", i);
if (rpmioFileExists(ofn)) {
- rpmMessage(RPMMESS_DEBUG, D_("removing region file \"%s\"\n"), ofn);
+ rpmlog(RPMLOG_DEBUG, D_("removing region file \"%s\"\n"), ofn);
xx = Unlink(ofn);
}
(void) snprintf(nsuffix, sizeof("000"), "%03d", i);
if (rpmioFileExists(nfn)) {
- rpmMessage(RPMMESS_DEBUG, D_("removing region file \"%s\"\n"), nfn);
+ rpmlog(RPMLOG_DEBUG, D_("removing region file \"%s\"\n"), nfn);
xx = Unlink(nfn);
}
}
@@ -3873,7 +3873,7 @@
/*@=nullpass@*/
if (!(tfn && tfn[0] != '\0'))
{
- rpmMessage(RPMMESS_DEBUG, D_("no dbpath has been set"));
+ rpmlog(RPMLOG_DEBUG, D_("no dbpath has been set"));
rc = 1;
goto exit;
}
@@ -3901,7 +3901,7 @@
newdbpath += strlen(prefix) - 1;
tfn = _free(tfn);
- rpmMessage(RPMMESS_DEBUG, D_("rebuilding database %s into %s\n"),
+ rpmlog(RPMLOG_DEBUG, D_("rebuilding database %s into %s\n"),
rootdbpath, newrootdbpath);
if (!Access(newrootdbpath, F_OK)) {
@@ -3911,7 +3911,7 @@
goto exit;
}
- rpmMessage(RPMMESS_DEBUG, D_("creating directory %s\n"), newrootdbpath);
+ rpmlog(RPMLOG_DEBUG, D_("creating directory %s\n"), newrootdbpath);
if (Mkdir(newrootdbpath, 0755)) {
rpmlog(RPMLOG_ERR, _("creating directory %s: %s\n"),
newrootdbpath, strerror(errno));
@@ -3922,7 +3922,7 @@
_rebuildinprogress = 0;
- rpmMessage(RPMMESS_DEBUG, D_("opening old database with dbapi %d\n"),
+ rpmlog(RPMLOG_DEBUG, D_("opening old database with dbapi %d\n"),
_dbapi);
if (rpmdbOpenDatabase(prefix, dbpath, _dbapi, &olddb, O_RDONLY, 0644,
RPMDB_FLAG_MINIMAL)) {
@@ -3931,7 +3931,7 @@
}
_dbapi = olddb->db_api;
_rebuildinprogress = 1;
- rpmMessage(RPMMESS_DEBUG, D_("opening new database with dbapi %d\n"),
+ rpmlog(RPMLOG_DEBUG, D_("opening new database with dbapi %d\n"),
_dbapi_rebuild);
(void) rpmDefineMacro(NULL, "_rpmdb_rebuild %{nil}", -1);
if (rpmdbOpenDatabase(prefix, newdbpath, _dbapi_rebuild, &newdb, O_RDWR | O_CREAT, 0644, 0)) {
@@ -4022,7 +4022,7 @@
xx = rpmdbClose(newdb);
if (failed) {
- rpmMessage(RPMMESS_NORMAL, _("failed to rebuild database: original database "
+ rpmlog(RPMLOG_NOTICE, _("failed to rebuild database: original database "
"remains in place\n"));
xx = rpmdbRemoveDatabase(prefix, newdbpath, _dbapi_rebuild,
@@ -4034,9 +4034,9 @@
dbiTags, dbiTagsMax);
if (xx) {
- rpmMessage(RPMMESS_ERROR, _("failed to replace old database with new "
+ rpmlog(RPMLOG_ERR, _("failed to replace old database with new "
"database!\n"));
- rpmMessage(RPMMESS_ERROR, _("replace files in %s with files from %s "
+ rpmlog(RPMLOG_ERR, _("replace files in %s with files from %s "
"to recover"), dbpath, newdbpath);
rc = 1;
goto exit;
@@ -4046,9 +4046,9 @@
exit:
if (removedir && !(rc == 0 && nocleanup)) {
- rpmMessage(RPMMESS_DEBUG, D_("removing directory %s\n"), newrootdbpath);
+ rpmlog(RPMLOG_DEBUG, D_("removing directory %s\n"), newrootdbpath);
if (Rmdir(newrootdbpath))
- rpmMessage(RPMMESS_ERROR, _("failed to remove directory %s: %s\n"),
+ rpmlog(RPMLOG_ERR, _("failed to remove directory %s: %s\n"),
newrootdbpath, strerror(errno));
}
newrootdbpath = _free(newrootdbpath);
@@ .
patch -p0 <<'@@ .'
Index: rpm/rpmdb/signature.c
============================================================================
$ cvs diff -u -r1.5 -r1.6 signature.c
--- rpm/rpmdb/signature.c 11 Oct 2007 19:14:41 -0000 1.5
+++ rpm/rpmdb/signature.c 11 Oct 2007 19:44:24 -0000 1.6
@@ -304,7 +304,7 @@
}
*pktlenp = st.st_size;
- rpmMessage(RPMMESS_DEBUG, D_("PGP sig size: %d\n"), *pktlenp);
+ rpmlog(RPMLOG_DEBUG, D_("PGP sig size: %d\n"), *pktlenp);
*pktp = xmalloc(*pktlenp);
{ FD_t fd;
@@ -323,7 +323,7 @@
}
}
- rpmMessage(RPMMESS_DEBUG, D_("Got %d bytes of PGP sig\n"), *pktlenp);
+ rpmlog(RPMLOG_DEBUG, D_("Got %d bytes of PGP sig\n"), *pktlenp);
#ifdef NOTYET
/* Parse the signature, change signature tag as appropriate. */
@@ -447,7 +447,7 @@
}
*pktlenp = st.st_size;
- rpmMessage(RPMMESS_DEBUG, D_("GPG sig size: %d\n"), *pktlenp);
+ rpmlog(RPMLOG_DEBUG, D_("GPG sig size: %d\n"), *pktlenp);
*pktp = xmalloc(*pktlenp);
{ FD_t fd;
@@ -466,7 +466,7 @@
}
}
- rpmMessage(RPMMESS_DEBUG, D_("Got %d bytes of GPG sig\n"), *pktlenp);
+ rpmlog(RPMLOG_DEBUG, D_("Got %d bytes of GPG sig\n"), *pktlenp);
/* Parse the signature, change signature tag as appropriate. */
dig = pgpNewDig(0);
@@ .
patch -p0 <<'@@ .'
Index: rpm/rpmdb/sqlite.c
============================================================================
$ cvs diff -u -r1.15 -r1.16 sqlite.c
--- rpm/rpmdb/sqlite.c 30 Sep 2007 17:29:05 -0000 1.15
+++ rpm/rpmdb/sqlite.c 11 Oct 2007 19:44:24 -0000 1.16
@@ -289,9 +289,9 @@
}
if (scp->pStmt) {
xx = sqlite3_reset(scp->pStmt);
- if (xx) rpmMessage(RPMMESS_WARNING, "reset %d\n", xx);
+ if (xx) rpmlog(RPMLOG_WARNING, "reset %d\n", xx);
xx = sqlite3_finalize(scp->pStmt);
- if (xx) rpmMessage(RPMMESS_WARNING, "finalize %d\n", xx);
+ if (xx) rpmlog(RPMLOG_WARNING, "finalize %d\n", xx);
scp->pStmt = NULL;
}
@@ -664,7 +664,7 @@
dbiIndex dbi = (dbiIndex) dbi_void;
/*@=castexpose@*/
- rpmMessage(RPMMESS_WARNING, _("Unable to get lock on db %s, retrying... (%d)\n"),
+ rpmlog(RPMLOG_WARNING, _("Unable to get lock on db %s, retrying... (%d)\n"),
dbi->dbi_file, time);
(void) sleep(1);
@@ -787,7 +787,7 @@
exit:
if (rc)
- rpmMessage(RPMMESS_WARNING, "Unable to initDB %s (%d)\n",
+ rpmlog(RPMLOG_WARNING, "Unable to initDB %s (%d)\n",
scp->pzErrmsg, rc);
scp = scpFree(scp);
@@ -856,7 +856,7 @@
(void) sqlite3_close(sqldb->db);
- rpmMessage(RPMMESS_DEBUG, D_("closed sql db %s\n"),
+ rpmlog(RPMLOG_DEBUG, D_("closed sql db %s\n"),
dbi->dbi_subfile);
#if defined(MAYBE) /* XXX should SQLite and BDB have different semantics? */
@@ -972,7 +972,7 @@
else
dbfname = rpmGenPath(dbhome, dbi->dbi_file, NULL);
- rpmMessage(RPMMESS_DEBUG, D_("opening sql db %s (%s) mode=0x%x\n"),
+ rpmlog(RPMLOG_DEBUG, D_("opening sql db %s (%s) mode=0x%x\n"),
dbfname, dbi->dbi_subfile, dbi->dbi_mode);
/* Open the Database */
@@ -1001,7 +1001,7 @@
dbi->dbi_db = (DB *)sqldb;
if (sql_errcode != NULL) {
- rpmMessage(RPMMESS_DEBUG, D_("Unable to open database: %s\n"), sql_errcode);
+ rpmlog(RPMLOG_DEBUG, D_("Unable to open database: %s\n"), sql_errcode);
rc = EINVAL;
}
@@ -1106,14 +1106,14 @@
dbi->dbi_subfile);
rc = sqlite3_prepare(sqldb->db, scp->cmd, strlen(scp->cmd), &scp->pStmt, &scp->pzErrmsg);
- if (rc) rpmMessage(RPMMESS_WARNING, "cdel(%s) prepare %s (%d)\n", dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
+ if (rc) rpmlog(RPMLOG_WARNING, "cdel(%s) prepare %s (%d)\n", dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
rc = sql_bind_key(dbi, scp, 1, key);
- if (rc) rpmMessage(RPMMESS_WARNING, "cdel(%s) bind key %s (%d)\n", dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
+ if (rc) rpmlog(RPMLOG_WARNING, "cdel(%s) bind key %s (%d)\n", dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
rc = sql_bind_data(dbi, scp, 2, data);
- if (rc) rpmMessage(RPMMESS_WARNING, "cdel(%s) bind data %s (%d)\n", dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
+ if (rc) rpmlog(RPMLOG_WARNING, "cdel(%s) bind data %s (%d)\n", dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
rc = sql_step(dbi, scp);
- if (rc) rpmMessage(RPMMESS_WARNING, "cdel(%s) sql_step rc %d\n", dbi->dbi_subfile, rc);
+ if (rc) rpmlog(RPMLOG_WARNING, "cdel(%s) sql_step rc %d\n", dbi->dbi_subfile, rc);
scp = scpFree(scp);
@@ -1184,10 +1184,10 @@
break;
}
rc = sqlite3_prepare(sqldb->db, scp->cmd, strlen(scp->cmd), &scp->pStmt, &scp->pzErrmsg);
- if (rc) rpmMessage(RPMMESS_WARNING, "cget(%s) sequential prepare %s (%d)\n", dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
+ if (rc) rpmlog(RPMLOG_WARNING, "cget(%s) sequential prepare %s (%d)\n", dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
rc = sql_step(dbi, scp);
- if (rc) rpmMessage(RPMMESS_WARNING, "cget(%s) sequential sql_step rc %d\n", dbi->dbi_subfile, rc);
+ if (rc) rpmlog(RPMLOG_WARNING, "cget(%s) sequential sql_step rc %d\n", dbi->dbi_subfile, rc);
scp = scpResetKeys(scp);
scp->nkeys = scp->nr;
@@ -1217,7 +1217,7 @@
scp->cmd = sqlite3_mprintf("SELECT value FROM '%q' WHERE key=?;", dbi->dbi_subfile);
rc = sqlite3_prepare(sqldb->db, scp->cmd, strlen(scp->cmd), &scp->pStmt, &scp->pzErrmsg);
- if (rc) rpmMessage(RPMMESS_WARNING, "cget(%s) prepare %s (%d)\n", dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
+ if (rc) rpmlog(RPMLOG_WARNING, "cget(%s) prepare %s (%d)\n", dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
}
/*@i@*/ scp = scpResetAv(scp); /* Free av and avlen, reset counters.*/
@@ -1231,13 +1231,13 @@
/* Bind key to prepared statement */
rc = sql_bind_key(dbi, scp, 1, scp->keys[scp->rx]);
- if (rc) rpmMessage(RPMMESS_WARNING, "cget(%s) key bind %s (%d)\n", dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
+ if (rc) rpmlog(RPMLOG_WARNING, "cget(%s) key bind %s (%d)\n", dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
rc = sql_step(dbi, scp);
- if (rc) rpmMessage(RPMMESS_WARNING, "cget(%s) sql_step rc %d\n", dbi->dbi_subfile, rc);
+ if (rc) rpmlog(RPMLOG_WARNING, "cget(%s) sql_step rc %d\n", dbi->dbi_subfile, rc);
rc = sqlite3_reset(scp->pStmt);
- if (rc) rpmMessage(RPMMESS_WARNING, "reset %d\n", rc);
+ if (rc) rpmlog(RPMLOG_WARNING, "reset %d\n", rc);
/* 1 key should return 0 or 1 row/value */
assert(scp->nr < 2);
@@ -1329,14 +1329,14 @@
scp->cmd = sqlite3_mprintf("INSERT OR REPLACE INTO '%q' VALUES(?, ?);",
dbi->dbi_subfile);
rc = sqlite3_prepare(sqldb->db, scp->cmd, strlen(scp->cmd), &scp->pStmt, &scp->pzErrmsg);
- if (rc) rpmMessage(RPMMESS_WARNING, "cput(%s) prepare %s (%d)\n",dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
+ if (rc) rpmlog(RPMLOG_WARNING, "cput(%s) prepare %s (%d)\n",dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
rc = sql_bind_key(dbi, scp, 1, key);
- if (rc) rpmMessage(RPMMESS_WARNING, "cput(%s) key bind %s (%d)\n", dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
+ if (rc) rpmlog(RPMLOG_WARNING, "cput(%s) key bind %s (%d)\n", dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
rc = sql_bind_data(dbi, scp, 2, data);
- if (rc) rpmMessage(RPMMESS_WARNING, "cput(%s) data bind %s (%d)\n", dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
+ if (rc) rpmlog(RPMLOG_WARNING, "cput(%s) data bind %s (%d)\n", dbi->dbi_subfile, sqlite3_errmsg(sqldb->db), rc);
rc = sql_step(dbi, scp);
- if (rc) rpmMessage(RPMMESS_WARNING, "cput(%s) sql_step rc %d\n", dbi->dbi_subfile, rc);
+ if (rc) rpmlog(RPMLOG_WARNING, "cput(%s) sql_step rc %d\n", dbi->dbi_subfile, rc);
break;
}
@@ -1380,10 +1380,10 @@
} else {
if ( sql_rc ) {
- rpmMessage(RPMMESS_DEBUG, D_("db_info failed %s (%d)\n"),
+ rpmlog(RPMLOG_DEBUG, D_("db_info failed %s (%d)\n"),
scp->pzErrmsg, sql_rc);
}
- rpmMessage(RPMMESS_WARNING, "Unable to determine DB endian.\n");
+ rpmlog(RPMLOG_WARNING, "Unable to determine DB endian.\n");
}
scp = scpFree(scp);
@@ -1526,11 +1526,11 @@
assert(scp->av != NULL);
nkeys = strtol(scp->av[1], NULL, 10);
- rpmMessage(RPMMESS_DEBUG, D_(" stat on %s nkeys %ld\n"),
+ rpmlog(RPMLOG_DEBUG, D_(" stat on %s nkeys %ld\n"),
dbi->dbi_subfile, nkeys);
} else {
if ( rc ) {
- rpmMessage(RPMMESS_DEBUG, D_("stat failed %s (%d)\n"),
+ rpmlog(RPMLOG_DEBUG, D_("stat failed %s (%d)\n"),
scp->pzErrmsg, rc);
}
}
@@ .
patch -p0 <<'@@ .'
Index: rpm/rpmio/rpmio.c
============================================================================
$ cvs diff -u -r1.95 -r1.96 rpmio.c
--- rpm/rpmio/rpmio.c 6 Oct 2007 21:33:50 -0000 1.95
+++ rpm/rpmio/rpmio.c 11 Oct 2007 19:44:24 -0000 1.96
@@ -1576,7 +1576,7 @@
fd = fdLink(fd, "grab ctrl (urlConnect FTP)");
if (fdFileno(u->ctrl) < 0) {
- rpmMessage(RPMMESS_DEBUG, D_("logging into %s as %s, pw %s\n"),
+ rpmlog(RPMLOG_DEBUG, D_("logging into %s as %s, pw %s\n"),
u->host ? u->host : "???",
u->user ? u->user : "ftp",
u->password ? u->password : "(username)");
@@ -3647,7 +3647,7 @@
}
rc = 0;
if (created)
- rpmMessage(RPMMESS_DEBUG, D_("created directory(s) %s mode 0%o\n"),
+ rpmlog(RPMLOG_DEBUG, D_("created directory(s) %s mode 0%o\n"),
path, mode);
return rc;
}
@@ .
patch -p0 <<'@@ .'
Index: rpm/rpmio/rpmlog.c
============================================================================
$ cvs diff -u -r2.33 -r2.34 rpmlog.c
--- rpm/rpmio/rpmlog.c 6 Oct 2007 19:40:23 -0000 2.33
+++ rpm/rpmio/rpmlog.c 11 Oct 2007 19:44:24 -0000 2.34
@@ -210,7 +210,7 @@
}
}
- /* rpmMessage behavior */
+ /* rpmlog behavior */
switch (pri) {
case RPMLOG_INFO:
@@ .
patch -p0 <<'@@ .'
Index: rpm/rpmio/url.c
============================================================================
$ cvs diff -u -r1.41 -r1.42 url.c
--- rpm/rpmio/url.c 6 Oct 2007 19:40:23 -0000 1.41
+++ rpm/rpmio/url.c 11 Oct 2007 19:44:24 -0000 1.42
@@ -479,7 +479,7 @@
char *end;
u->port = strtol(u->portstr, &end, 0);
if (!(end && *end == '\0')) {
- rpmMessage(RPMMESS_ERROR, _("url port must be a number\n"));
+ rpmlog(RPMLOG_ERR, _("url port must be a number\n"));
myurl = _free(myurl);
u = urlFree(u, "urlSplit (error #3)");
return -1;
@@ -530,7 +530,7 @@
sfd = Fopen(url, "r");
if (sfd == NULL || Ferror(sfd)) {
- rpmMessage(RPMMESS_DEBUG, D_("failed to open %s: %s\n"), url, Fstrerror(sfd));
+ rpmlog(RPMLOG_DEBUG, D_("failed to open %s: %s\n"), url, Fstrerror(sfd));
rc = FTPERR_UNKNOWN;
goto exit;
}
@@ -550,7 +550,7 @@
if (_url_debug)
fprintf(stderr, "*** urlGetFile sfd %p %s tfd %p %s\n", sfd, url, (tfd ? tfd : NULL), dest);
if (tfd == NULL || Ferror(tfd)) {
- rpmMessage(RPMMESS_DEBUG, D_("failed to create %s: %s\n"), dest, Fstrerror(tfd));
+ rpmlog(RPMLOG_DEBUG, D_("failed to create %s: %s\n"), dest, Fstrerror(tfd));
rc = FTPERR_UNKNOWN;
goto exit;
}
@@ .
patch -p0 <<'@@ .'
Index: rpm/tools/rpmcache.c
============================================================================
$ cvs diff -u -r2.15 -r2.16 rpmcache.c
--- rpm/tools/rpmcache.c 29 Sep 2007 19:29:02 -0000 2.15
+++ rpm/tools/rpmcache.c 11 Oct 2007 19:44:25 -0000 2.16
@@ -177,7 +177,7 @@
int ec = -1; /* assume not found */
int i = 0;
- rpmMessage(RPMMESS_DEBUG, "============== %s\n", fts->fts_accpath);
+ rpmlog(RPMLOG_DEBUG, "============== %s\n", fts->fts_accpath);
/* XXX DIEDIEDIE: check platform compatibility. */
@@ -467,7 +467,7 @@
bhglobs[i].patterns[0] = pattern;
bhglobs[i].fnflags = (FNM_PATHNAME | FNM_PERIOD | FNM_EXTMATCH);
if (bhglobs[i].patterns[0] != NULL)
- rpmMessage(RPMMESS_DEBUG, "\t%d \"%s\"\n",
+ rpmlog(RPMLOG_DEBUG, "\t%d \"%s\"\n",
i, bhglobs[i].patterns[0]);
}
}
@@ .
Received on Thu Oct 11 21:44:25 2007
Index: rpm/lib/rpmgi.c
============================================================================
$ cvs diff -u -r2.35 -r2.36 rpmgi.c
--- rpm/lib/rpmgi.c 11 Oct 2007 19:14:37 -0000 2.35
+++ rpm/lib/rpmgi.c 11 Oct 2007 19:44:22 -0000 2.36
@@ -245,7 +245,7 @@
const char * s;
if (_rpmgi_debug < 0)
-rpmMessage(RPMMESS_DEBUG, "FTS_%s\t%*s %s%s\n", ftsInfoStr(fts->fts_info),
+rpmlog(RPMLOG_DEBUG, "FTS_%s\t%*s %s%s\n", ftsInfoStr(fts->fts_info),
indent * (fts->fts_level < 0 ? 0 : fts->fts_level), "",
fts->fts_name,
((fts->fts_info == FTS_D || fts->fts_info == FTS_DP) ? "/" : ""));
@@ -762,20 +762,20 @@
/* XXX query/verify will need the glop added to a buffer instead. */
ps = rpmtsProblems(ts);
if (rpmpsNumProblems(ps) > 0) {
- /* XXX rpminstall will need RPMMESS_ERROR */
- rpmMessage(RPMMESS_VERBOSE, _("Failed dependencies:\n"));
+ /* XXX rpminstall will need RPMLOG_ERR */
+ rpmlog(RPMLOG_INFO, _("Failed dependencies:\n"));
if (rpmIsVerbose())
rpmpsPrint(NULL, ps);
if (ts->suggests != NULL && ts->nsuggests > 0) {
- rpmMessage(RPMMESS_VERBOSE, _(" Suggested resolutions:\n"));
+ rpmlog(RPMLOG_INFO, _(" Suggested resolutions:\n"));
for (i = 0; i < ts->nsuggests; i++) {
const char * str = ts->suggests[i];
if (str == NULL)
break;
- rpmMessage(RPMMESS_VERBOSE, "\t%s\n", str);
+ rpmlog(RPMLOG_INFO, "\t%s\n", str);
ts->suggests[i] = NULL;
str = _free(str);
@@ .
patch -p0 <<'@@ .'